@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -154,31 +154,31 @@ void EnumValueHandler::startDetailedDesc(const QXmlAttributes& attrib)
 //------------------------------------------------------------------------------
 
 MemberHandler::MemberHandler(IBaseHandler *parent)
-  : m_parent(parent), m_compound(0), m_brief(0), m_detailed(0)
+  : m_brief(0), m_detailed(0), m_inbody(0), 
+    m_compound(0), m_section(0), m_parent(parent)
 {
   //printf("MemberHandler::MemberHandler() %p\n",this);
   addEndHandler("memberdef",this,&MemberHandler::endMember);
-  addEndHandler("enumvalue",this,&MemberHandler::endMember);
+
+  addStartHandler("templateparamlist",this,&MemberHandler::startTemplateParamList);
+  addEndHandler("templateparamlist",this,&MemberHandler::endTemplateParamList);
 
   addStartHandler("type",this,&MemberHandler::startType);
-  addStartHandler("initializer",this,&MemberHandler::startInitializer);
-  addStartHandler("exception",this,&MemberHandler::startException);
-  addStartHandler("enumvalue",this,&MemberHandler::startEnumValue2);
+
+  addStartHandler("definition",this,&MemberHandler::startDefinition);
+  addEndHandler("definition",this,&MemberHandler::endDefinition);
+
+  addStartHandler("argsstring",this,&MemberHandler::startArgsString);
+  addEndHandler("argsstring",this,&MemberHandler::endArgsString);
 
   addStartHandler("name",this,&MemberHandler::startName);
   addEndHandler("name",this,&MemberHandler::endName);
 
-  addStartHandler("param",this,&MemberHandler::startParam);
+  addStartHandler("read",this,&MemberHandler::startRead);
+  addEndHandler("read",this,&MemberHandler::endRead);
 
-  addStartHandler("briefdescription",this,&MemberHandler::startBriefDesc);
-
-  addStartHandler("detaileddescription",this,&MemberHandler::startDetailedDesc);
-
-  addStartHandler("references",this,&MemberHandler::startReferences);
-  addEndHandler("references",this,&MemberHandler::endReferences);
-  
-  addStartHandler("referencedby",this,&MemberHandler::startReferencedBy);
-  addEndHandler("referencedby",this,&MemberHandler::endReferencedBy);
+  addStartHandler("write",this,&MemberHandler::startWrite);
+  addEndHandler("write",this,&MemberHandler::endWrite);
 
   addStartHandler("reimplements",this,&MemberHandler::startReimplements);
   addEndHandler("reimplements",this,&MemberHandler::endReimplements);
@@ -186,11 +186,28 @@ MemberHandler::MemberHandler(IBaseHandler *parent)
   addStartHandler("reimplementedby",this,&MemberHandler::startReimplementedBy);
   addEndHandler("reimplementedby",this,&MemberHandler::endReimplementedBy);
 
+  addStartHandler("param",this,&MemberHandler::startParam);
+
+  addStartHandler("enumvalue",this,&MemberHandler::startEnumValue2);
+  addEndHandler("enumvalue",this,&MemberHandler::endMember);
+
+  addStartHandler("initializer",this,&MemberHandler::startInitializer);
+  addStartHandler("exceptions",this,&MemberHandler::startException);
+
+  addStartHandler("briefdescription",this,&MemberHandler::startBriefDesc);
+
+  addStartHandler("detaileddescription",this,&MemberHandler::startDetailedDesc);
+
+  addStartHandler("inbodydescription",this,&MemberHandler::startInbodyDesc);
+  
   addStartHandler("location",this,&MemberHandler::startLocation);
   addEndHandler("location");
 
-  addStartHandler("templateparamlist",this,&MemberHandler::startTemplateParamList);
-  addEndHandler("templateparamlist",this,&MemberHandler::endTemplateParamList);
+  addStartHandler("references",this,&MemberHandler::startReferences);
+  addEndHandler("references",this,&MemberHandler::endReferences);
+  
+  addStartHandler("referencedby",this,&MemberHandler::startReferencedBy);
+  addEndHandler("referencedby",this,&MemberHandler::endReferencedBy);
 
   m_type.setAutoDelete(TRUE);
   m_initializer.setAutoDelete(TRUE);
@@ -214,6 +231,7 @@ MemberHandler::~MemberHandler()
   debug(2,"MemberHandler::~MemberHandler() %p\n",this);
   delete m_brief;
   delete m_detailed;
+  delete m_inbody;
   delete m_linkedTextHandler;
   delete m_reimplements;
 }
@@ -222,13 +240,20 @@ void MemberHandler::startMember(const QXmlAttributes& attrib)
 {
   m_parent->setDelegate(this);
   m_kindString = attrib.value("kind");
-  printf("startMember kindString=`%s'\n",m_kindString.data());
+  //printf("startMember kindString=`%s'\n",m_kindString.data());
   m_kind = s_typeMap->map(m_kindString);
   m_id = attrib.value("id");
-  m_virtualness = attrib.value("virt");
   m_protection = attrib.value("prot");
+  m_isStatic = attrib.value("static")=="yes";
   m_isConst = attrib.value("const")=="yes";
+  m_isExplicit = attrib.value("explicit")=="yes";
+  m_isInline = attrib.value("inline")=="yes";
+  m_virtualness = attrib.value("virt");
   m_isVolatile = attrib.value("volatile")=="yes";
+  m_isMutable = attrib.value("mutable")=="yes";
+  m_isReadable = attrib.value("readable")=="yes";
+  m_isWritable = attrib.value("writable")=="yes";
+
   debug(2,"member kind=`%s' id=`%s' prot=`%s' virt=`%s'\n",
       m_kindString.data(),m_id.data(),m_protection.data(),m_virtualness.data());
 }
@@ -237,13 +262,19 @@ void MemberHandler::startEnumValue(const QXmlAttributes& attrib)
 {
   m_parent->setDelegate(this);
   m_kindString = "enumvalue";
-  printf("startEnumValue kindString=`%s'\n",m_kindString.data());
+  //printf("startEnumValue kindString=`%s'\n",m_kindString.data());
   m_kind = s_typeMap->map(m_kindString);
   m_id = attrib.value("id");
-  m_virtualness = "non-virtual";
   m_protection = attrib.value("prot");
+  m_isStatic = FALSE;
   m_isConst = FALSE;
+  m_isExplicit = FALSE;
+  m_isInline = FALSE;
+  m_virtualness = "non-virtual";
   m_isVolatile = FALSE;
+  m_isMutable = FALSE;
+  m_isReadable = FALSE;
+  m_isWritable = FALSE;
   debug(2,"member kind=`%s' id=`%s' prot=`%s' virt=`%s'\n",
       m_kindString.data(),m_id.data(),m_protection.data(),m_virtualness.data());
 }
@@ -270,9 +301,17 @@ void MemberHandler::startDetailedDesc(const QXmlAttributes& attrib)
   m_detailed = docHandler;
 }
 
+void MemberHandler::startInbodyDesc(const QXmlAttributes& attrib)
+{
+  DocHandler *docHandler = new DocHandler(this);
+  docHandler->startDoc(attrib);
+  m_inbody = docHandler;
+}
+
 void MemberHandler::startLocation(const QXmlAttributes& attrib)
 {
   m_defFile = attrib.value("file");
+  m_bodyFile = attrib.value("bodyfile");
   QCString s;
   s = attrib.value("line");
   if (!s.isEmpty()) m_defLine=s.toInt();
@@ -359,7 +398,7 @@ void MemberHandler::startException(const QXmlAttributes &)
   debug(2,"startException!\n");
   delete m_linkedTextHandler;
   m_linkedTextHandler = new LinkedTextHandler(this,m_exception);
-  m_linkedTextHandler->start("exception");
+  m_linkedTextHandler->start("exceptions");
 }
 
 void MemberHandler::startName(const QXmlAttributes &)
@@ -373,6 +412,50 @@ void MemberHandler::endName()
   debug(2,"member name=`%s'\n",m_name.data());
 }
 
+void MemberHandler::startRead(const QXmlAttributes &)
+{
+  m_curString="";
+}
+
+void MemberHandler::endRead()
+{
+  m_read = m_curString.stripWhiteSpace();
+  debug(2,"member read=`%s'\n",m_read.data());
+}
+
+void MemberHandler::startWrite(const QXmlAttributes &)
+{
+  m_curString="";
+}
+
+void MemberHandler::endWrite()
+{
+  m_write = m_curString.stripWhiteSpace();
+  debug(2,"member write=`%s'\n",m_write.data());
+}
+
+void MemberHandler::startDefinition(const QXmlAttributes&)
+{
+  m_curString="";
+}
+
+void MemberHandler::endDefinition()
+{
+  m_definition = m_curString.stripWhiteSpace();
+  debug(2,"definition=%s\n",m_definition.data());
+}
+  
+void MemberHandler::startArgsString(const QXmlAttributes&)
+{
+  m_curString="";
+}
+
+void MemberHandler::endArgsString()
+{
+  m_argsstring = m_curString.stripWhiteSpace();
+  debug(2,"arggstring=%s\n",m_argsstring.data());
+}
+  
 void MemberHandler::startParam(const QXmlAttributes& attrib)
 {
   ParamHandler *paramHandler = new ParamHandler(this);
@@ -510,3 +593,8 @@ IDocRoot *MemberHandler::detailedDescription() const
   return m_detailed; 
 }
 
+IDocRoot *MemberHandler::inbodyDescription() const
+{ 
+  return m_inbody; 
+}
+
