@@ -93,6 +93,7 @@ ClassDef::ClassDef(
   m_isAbstract = FALSE;
   m_isStatic = FALSE;
   m_isObjC = FALSE;
+  m_isTemplArg = FALSE;
   m_membersMerged = FALSE;
   m_categoryOf = 0;
   QCString ns;
@@ -876,7 +877,7 @@ void ClassDef::writeDetailedDescription(OutputList &ol, const QCString &pageType
 {
   if ((!briefDescription().isEmpty() && Config_getBool("REPEAT_BRIEF")) || 
       !documentation().isEmpty() || 
-      /*(Config_getBool("SOURCE_BROWSER") && startBodyLine!=-1 && bodyDef) ||*/
+      (Config_getBool("SOURCE_BROWSER") && getStartBodyLine()!=-1 && getBodyDef()) ||
       exampleFlag)
   {
     ol.writeRuler();
@@ -1024,7 +1025,7 @@ void ClassDef::writeDocumentation(OutputList &ol)
               m_compType == Interface && m_isObjC ? Class : m_compType,
               m_tempArgs != 0);
   
-  startFile(ol,getOutputFileBase(),name(),pageTitle);  
+  startFile(ol,getOutputFileBase(),name(),pageTitle,HLI_ClassVisible);  
   if (getOuterScope()!=Doxygen::globalScope)
   {
     writeNavigationPath(ol);
@@ -1034,6 +1035,30 @@ void ClassDef::writeDocumentation(OutputList &ol)
   addGroupListToTitle(ol,this);
   endTitle(ol,getOutputFileBase(),name());
 
+  {
+    ol.pushGeneratorState();
+    ol.disableAllBut(OutputGenerator::Html);
+    ol.writeString("<!-- doxytag: class=\"");
+    ol.docify(name());
+    ol.writeString("\" -->");
+    if (m_inherits->count()>0)
+    {
+      BaseClassListIterator bli(*m_inherits);
+      ol.writeString("<!-- doxytag: inherits=\"");
+      BaseClassDef *bcd=0;
+      bool first=TRUE;
+      for (bli.toFirst();(bcd=bli.current());++bli)
+      {
+        if (!first) ol.writeString(",");
+        ol.docify(bcd->classDef->name());
+        first=FALSE;
+      }
+      ol.writeString("\" -->");
+    }
+    ol.popGeneratorState();
+  }
+
+
   if (Config_getBool("SEARCHENGINE"))
   {
     Doxygen::searchIndex->setCurrentDoc(pageTitle,getOutputFileBase());
@@ -1340,6 +1365,11 @@ void ClassDef::writeDocumentation(OutputList &ol)
     writeDetailedDescription(ol,pageType,exampleFlag);
   }
 
+
+  ///////////////////////////////////////////////////////////////////////////
+  //// Member declarations + brief descriptions
+  ///////////////////////////////////////////////////////////////////////////
+
   // write member groups
   ol.startMemberSections();
 
@@ -1428,7 +1458,7 @@ void ClassDef::writeDocumentation(OutputList &ol)
 
   // nested classes
   m_innerClasses->writeDeclaration(ol,0,0,TRUE);
-  
+
   ol.endMemberSections();
     
   // write detailed description
@@ -1436,6 +1466,54 @@ void ClassDef::writeDocumentation(OutputList &ol)
     writeDetailedDescription(ol,pageType,exampleFlag);
   }
   
+  writeMemberDocumentation(ol);
+
+  /////////////////////////////////////////////////////////////////////
+  ol.startTextBlock();
+
+  // write the list of used files (not for man pages)
+  ol.pushGeneratorState();
+  ol.disable(OutputGenerator::Man);
+
+  showUsedFiles(ol);
+
+  // write Author section (Man only)
+  ol.enable(OutputGenerator::Man);
+  ol.disableAllBut(OutputGenerator::Man);
+  ol.writeString("\n");
+  ol.startGroupHeader();
+  ol.parseText(theTranslator->trAuthor(TRUE,TRUE));
+  ol.endGroupHeader();
+  ol.parseText(theTranslator->trGeneratedAutomatically(Config_getString("PROJECT_NAME")));
+  ol.popGeneratorState();
+
+  ol.endTextBlock();
+  /////////////////////////////////////////////////////////////////////
+
+  if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+  {
+    writeDocAnchorsToTagFile();
+    Doxygen::tagFile << "  </compound>" << endl;
+  }
+ 
+  endFile(ol);
+
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  {
+    writeMemberPages(ol);
+  }
+}
+
+void ClassDef::writeMemberDocumentation(OutputList &ol)
+{
+  ///////////////////////////////////////////////////////////////////////////
+  //// Member definitions + detailed documentation
+  ///////////////////////////////////////////////////////////////////////////
+
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  {
+    ol.disable(OutputGenerator::Html);
+  }
   
   typedefMembers.writeDocumentation(ol,name(),this,
                          theTranslator->trMemberTypedefDocumentation());
@@ -1461,36 +1539,80 @@ void ClassDef::writeDocumentation(OutputList &ol)
   eventMembers.writeDocumentation(ol,name(),this,
                          theTranslator->trEventDocumentation());
 
-  ol.startTextBlock();
-
-  // write the list of used files (not for man pages)
-  ol.pushGeneratorState();
-  ol.disable(OutputGenerator::Man);
-
-  showUsedFiles(ol);
-
-  // write Author section (Man only)
-  ol.enable(OutputGenerator::Man);
-  ol.disableAllBut(OutputGenerator::Man);
-  ol.writeString("\n");
-  ol.startGroupHeader();
-  ol.parseText(theTranslator->trAuthor(TRUE,TRUE));
-  ol.endGroupHeader();
-  ol.parseText(theTranslator->trGeneratedAutomatically(Config_getString("PROJECT_NAME")));
-  ol.popGeneratorState();
-
-  ol.endTextBlock();
-
-  if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
-    writeDocAnchorsToTagFile();
-    Doxygen::tagFile << "  </compound>" << endl;
+    ol.enable(OutputGenerator::Html);
   }
- 
-  endFile(ol);
-
 }
 
+void ClassDef::writeMemberPages(OutputList &ol)
+{
+  ///////////////////////////////////////////////////////////////////////////
+  //// Member definitions on separate pages
+  ///////////////////////////////////////////////////////////////////////////
+
+  ol.pushGeneratorState();
+  ol.disableAllBut(OutputGenerator::Html);
+  
+  typedefMembers.writeDocumentationPage(ol,name(),this);
+  enumMembers.writeDocumentationPage(ol,name(),this);
+  constructors.writeDocumentationPage(ol,name(),this);
+  functionMembers.writeDocumentationPage(ol,name(),this);
+  relatedMembers.writeDocumentationPage(ol,name(),this);
+  variableMembers.writeDocumentationPage(ol,name(),this);
+  propertyMembers.writeDocumentationPage(ol,name(),this);
+  eventMembers.writeDocumentationPage(ol,name(),this);
+
+  ol.popGeneratorState();
+}
+
+void ClassDef::writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const
+{
+  static bool createSubDirs=Config_getBool("CREATE_SUBDIRS");
+
+  ol.writeString("      <div class=\"navtab\">\n");
+  ol.writeString("        <table>\n");
+
+  MemberNameInfoSDict::Iterator mnili(*m_allMemberNameInfoSDict);
+  MemberNameInfo *mni;
+  for (;(mni=mnili.current());++mnili)
+  {
+    MemberNameInfoIterator mnii(*mni);
+    MemberInfo *mi;
+    for (mnii.toFirst();(mi=mnii.current());++mnii)
+    {
+      MemberDef *md=mi->memberDef;
+      if (md->getClassDef()==this && md->isLinkable())
+      {
+        ol.writeString("          <tr><td class=\"navtab\">");
+        if (md->isLinkableInProject())
+        {
+          if (md==currentMd) // selected item => highlight
+          {
+            ol.writeString("<a class=\"qindexHL\" ");
+          }
+          else
+          {
+            ol.writeString("<a class=\"qindex\" ");
+          }
+          ol.writeString("href=\"");
+          if (createSubDirs) ol.writeString("../../");
+          ol.writeString(md->getOutputFileBase()+Doxygen::htmlFileExtension+"#"+md->anchor());
+          ol.writeString("\">");
+          ol.writeString(md->name());
+          ol.writeString("</a>");
+        }
+        ol.writeString("</td></tr>\n");
+      }
+    }
+  }
+
+  ol.writeString("        </table>\n");
+  ol.writeString("      </div>\n");
+}
+
+
+
 void ClassDef::writeDocumentationForInnerClasses(OutputList &ol)
 {
   // write inner classes after the parent, so the tag files contain
@@ -1524,7 +1646,7 @@ void ClassDef::writeMemberList(OutputList &ol)
   ol.disableAllBut(OutputGenerator::Html);
 
   startFile(ol,m_memListFileName,m_memListFileName,
-            theTranslator->trMemberList());
+            theTranslator->trMemberList(),HLI_ClassVisible);
   startTitle(ol,0);
   ol.parseText(displayName()+" "+theTranslator->trMemberList());
   endTitle(ol,0,0);
@@ -1762,8 +1884,11 @@ void ClassDef::setTemplateArguments(ArgumentList *al)
  */
 bool ClassDef::hasNonReferenceSuperClass()
 {
-  bool found=!isReference(); 
-  if (found) return TRUE; // we're done if this class is not a reference
+  bool found=!isReference() && isLinkableInProject() && !isHidden(); 
+  if (found) 
+  {
+    return TRUE; // we're done if this class is not a reference
+  }
   BaseClassListIterator bcli(*m_inheritedBy);
   for ( ; bcli.current() && !found ; ++bcli ) // for each super class
   {
@@ -1901,7 +2026,7 @@ bool ClassDef::isLinkableInProject() const
   else
   {
     return !name().isEmpty() &&    /* no name */
-      !m_artificial &&
+      !m_artificial && !isHidden() &&
       name().find('@')==-1 && /* anonymous compound */
       (m_prot!=Private || Config_getBool("EXTRACT_PRIVATE")) && /* private */
       (!m_isLocal || Config_getBool("EXTRACT_LOCAL_CLASSES")) && /* local */
@@ -1982,12 +2107,9 @@ bool ClassDef::isBaseClass(ClassDef *bcd, bool followInstances,int level)
 
 static bool isStandardFunc(MemberDef *md)
 {
-  ClassDef *cd=md->getClassDef();
-  if (cd->templateMaster()) cd=cd->templateMaster();
   return md->name()=="operator=" || // assignment operator
-         md->name()==cd->localName() || // constructor
-         (md->name().find('~')!=-1 && 
-          md->name().find("operator")==-1); // destructor
+         md->isConstructor() ||     // constructor
+         md->isDestructor();        // destructor
 }
 
 /*! 
@@ -2047,8 +2169,11 @@ void ClassDef::mergeMembers()
               if (srcCd==dstCd || dstCd->isBaseClass(srcCd,TRUE)) 
                 // member is in the same or a base class
               {
-                found=matchArguments(srcMd->argumentList(),
-                    dstMd->argumentList());
+                found=matchArguments2(
+                    srcMd->getOuterScope(),srcMd->getFileDef(),srcMd->argumentList(),
+                    dstMd->getOuterScope(),dstMd->getFileDef(),dstMd->argumentList(),
+                    TRUE
+                   );
                 //printf("  Yes, matching (%s<->%s): %d\n",
                 //    argListToString(srcMd->argumentList()).data(),
                 //    argListToString(dstMd->argumentList()).data(),
@@ -2265,6 +2390,7 @@ void ClassDef::mergeCategory(ClassDef *category)
 
 void ClassDef::addUsedClass(ClassDef *cd,const char *accessName)
 {
+  //printf("%s::addUsedClass(%s,%s)\n",name().data(),cd->name().data(),accessName);
   if (m_usesImplClassDict==0) 
   {
     m_usesImplClassDict = new UsesClassDict(17); 
@@ -2326,7 +2452,7 @@ void ClassDef::determineImplUsageRelation()
         QCString usedClassName;
         QCString templSpec;
         bool found=FALSE;
-        while (extractClassNameFromType(type,pos,usedClassName,templSpec) && !found)
+        while (extractClassNameFromType(type,pos,usedClassName,templSpec)!=-1 && !found)
         {
           //printf("usedClassName=`%s' templSpec=%s\n",usedClassName.data(),templSpec.data());
           // check if usedClassName is a template argument of its class
@@ -2653,6 +2779,7 @@ ClassDef *ClassDef::insertTemplateInstance(const QCString &fileName,
         fileName,startLine,name()+templSpec,ClassDef::Class);
     templateClass->setTemplateMaster(this);
     templateClass->setOuterScope(getOuterScope());
+    templateClass->setHidden(isHidden());
     m_templateInstances->insert(templSpec,templateClass);
     freshInstance=TRUE;
   }
@@ -2788,6 +2915,7 @@ void ClassDef::getTemplateParameterLists(QList<ArgumentList> &lists) const
 QCString ClassDef::qualifiedNameWithTemplateParameters(
     QList<ArgumentList> *actualParams) const
 {
+  static bool optimizeOutputJava = Config_getBool("OPTIMIZE_OUTPUT_JAVA");
   //printf("qualifiedNameWithTemplateParameters() localName=%s\n",localName().data());
   QCString scName;
   Definition *d=getOuterScope();
@@ -2805,7 +2933,7 @@ QCString ClassDef::qualifiedNameWithTemplateParameters(
   }
 
   QCString scopeSeparator;
-  if (Config_getBool("OPTIMIZE_OUTPUT_JAVA")) 
+  if (optimizeOutputJava)
     scopeSeparator=".";
   else
     scopeSeparator="::";
