@@ -67,7 +67,7 @@ class ClassDef : public Definition
                         Category=Entry::CATEGORY_SEC,
                         Exception=Entry::EXCEPTION_SEC
                       };
-    DefType definitionType() { return TypeClass; }
+    DefType definitionType() const { return TypeClass; }
     QCString getOutputFileBase() const; 
     QCString getInstanceOutputFileBase() const; 
     QCString getFileBase() const;
@@ -104,9 +104,12 @@ class ClassDef : public Definition
 
     void writeDocumentation(OutputList &ol);
     void writeDocumentationForInnerClasses(OutputList &ol);
+    void writeMemberDocumentation(OutputList &ol);
+    void writeMemberPages(OutputList &ol);
     void writeMemberList(OutputList &ol);
     void writeDeclaration(OutputList &ol,MemberDef *md,bool inGroup);
     void writeDetailedDescription(OutputList &ol,const QCString &pageType,bool exampleFlag);
+    void writeQuickMemberLinks(OutputList &ol,MemberDef *md) const;
 
     /*! Return the protection level (Public,Protected,Private) in which 
      *  this compound was found.
@@ -180,6 +183,17 @@ class ClassDef : public Definition
       return m_usesIntfClassDict;
     }
 
+    /** Marks this class as a template argument of some another class */
+    void makeTemplateArgument(bool b=TRUE)
+    {
+      m_isTemplArg = b;
+    }
+
+    bool isTemplateArgument() const
+    {
+      return m_isTemplArg;
+    }
+
     /*! Returns the definition of a nested compound if
      *  available, or 0 otherwise.
      *  @param name The name of the nested compound
@@ -302,6 +316,7 @@ class ClassDef : public Definition
     void setIsStatic(bool b) { m_isStatic=b; }
     void setIsObjectiveC(bool b) { m_isObjC=b; }
     void addListReferences();
+    void setCompoundType(CompoundType t) { m_compType = t; } 
 
     /*! Creates a new compound definition.
      *  \param fileName  full path and file name in which this compound was
@@ -461,6 +476,8 @@ class ClassDef : public Definition
      *  class which is extended.
      */
     ClassDef *m_categoryOf;
+
+    bool m_isTemplArg;
 };
 
 /*! \brief Class that contains information about a usage relation. 
