@@ -21,6 +21,7 @@
 "      <xsd:element name=\"includedby\" type=\"incType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"incdepgraph\" type=\"graphType\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"invincdepgraph\" type=\"graphType\" minOccurs=\"0\" />\n"
+"      <xsd:element name=\"innerdir\" type=\"refType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"innerfile\" type=\"refType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"innerclass\" type=\"refType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"innernamespace\" type=\"refType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
@@ -36,8 +37,9 @@
 "      <xsd:element name=\"location\" type=\"locationType\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"listofallmembers\" type=\"listofallmembersType\" minOccurs=\"0\" />\n"
 "    </xsd:sequence>\n"
-"    <xsd:attribute name=\"id\" />\n"
+"    <xsd:attribute name=\"id\" type=\"xsd:string\" />\n"
 "    <xsd:attribute name=\"kind\" type=\"DoxCompoundKind\" />\n"
+"    <xsd:attribute name=\"prot\" type=\"DoxProtectionKind\" />\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"listofallmembersType\">\n"
@@ -51,40 +53,61 @@
 "      <xsd:element name=\"scope\" />\n"
 "      <xsd:element name=\"name\" />\n"
 "    </xsd:sequence>\n"
-"    <xsd:attribute name=\"refid\" />\n"
+"    <xsd:attribute name=\"refid\" type=\"xsd:string\" />\n"
 "    <xsd:attribute name=\"prot\" type=\"DoxProtectionKind\" />\n"
 "    <xsd:attribute name=\"virt\" type=\"DoxVirtualKind\" />\n"
 "    <xsd:attribute name=\"ambiguityscope\" type=\"xsd:string\" />\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"compoundRefType\" mixed=\"true\">\n"
-"    <xsd:attribute name=\"refid\" />\n"
-"    <xsd:attribute name=\"prot\" type=\"DoxProtectionKind\" />\n"
-"    <xsd:attribute name=\"virt\" type=\"DoxVirtualKind\" />\n"
+"    <xsd:simpleContent>\n"
+"      <xsd:extension base=\"xsd:string\">\n"
+"        <xsd:attribute name=\"refid\" type=\"xsd:string\" use=\"optional\" />\n"
+"        <xsd:attribute name=\"prot\" type=\"DoxProtectionKind\" />\n"
+"        <xsd:attribute name=\"virt\" type=\"DoxVirtualKind\" />\n"
+"      </xsd:extension>\n"
+"    </xsd:simpleContent>\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"reimplementType\" mixed=\"true\">\n"
-"    <xsd:attribute name=\"refid\" />\n"
+"    <xsd:simpleContent>\n"
+"      <xsd:extension base=\"xsd:string\">\n"
+"        <xsd:attribute name=\"refid\" type=\"xsd:string\" />\n"
+"      </xsd:extension>\n"
+"    </xsd:simpleContent>\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"incType\" mixed=\"true\">\n"
-"    <xsd:attribute name=\"refid\" />\n"
-"    <xsd:attribute name=\"local\" type=\"DoxBool\" />\n"
+"    <xsd:simpleContent>\n"
+"      <xsd:extension base=\"xsd:string\">\n"
+"        <xsd:attribute name=\"refid\" type=\"xsd:string\" />\n"
+"        <xsd:attribute name=\"local\" type=\"DoxBool\" />\n"
+"      </xsd:extension>\n"
+"    </xsd:simpleContent>\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"refType\" mixed=\"true\">\n"
-"    <xsd:attribute name=\"refid\" />\n"
+"    <xsd:simpleContent>\n"
+"      <xsd:extension base=\"xsd:string\">\n"
+"        <xsd:attribute name=\"refid\" type=\"xsd:string\" />\n"
+"      </xsd:extension>\n"
+"    </xsd:simpleContent>\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"refTextType\" mixed=\"true\">\n"
-"    <xsd:attribute name=\"refid\" />\n"
-"    <xsd:attribute name=\"kindref\" />\n"
-"    <xsd:attribute name=\"external\" />\n"
+"    <xsd:simpleContent>\n"
+"      <xsd:extension base=\"xsd:string\">\n"
+"       <xsd:attribute name=\"refid\" type=\"xsd:string\" />\n"
+"       <xsd:attribute name=\"kindref\" type=\"DoxRefKind\" />\n"
+"       <xsd:attribute name=\"external\" type=\"xsd:string\" />\n"
+"      </xsd:extension>\n"
+"    </xsd:simpleContent>\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"sectiondefType\">\n"
 "    <xsd:sequence>\n"
 "      <xsd:element name=\"header\" type=\"xsd:string\" minOccurs=\"0\" />\n"
+"      <xsd:element name=\"description\" type=\"descriptionType\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"memberdef\" type=\"memberdefType\" maxOccurs=\"unbounded\" />\n"
 "    </xsd:sequence>\n"
 "    <xsd:attribute name=\"kind\" type=\"DoxSectionKind\" />\n"
@@ -92,10 +115,13 @@
 "\n"
 "  <xsd:complexType name=\"memberdefType\">\n"
 "    <xsd:sequence>\n"
+"      <xsd:element name=\"templateparamlist\" type=\"templateparamlistType\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"type\" type=\"linkedTextType\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"definition\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"argsstring\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"name\" />\n"
+"      <xsd:element name=\"read\" minOccurs=\"0\" />\n"
+"      <xsd:element name=\"write\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"reimplements\" type=\"reimplementType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"reimplementedby\" type=\"reimplementType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"param\" type=\"paramType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
@@ -104,12 +130,13 @@
 "      <xsd:element name=\"exceptions\" type=\"linkedTextType\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"briefdescription\" type=\"descriptionType\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"detaileddescription\" type=\"descriptionType\" minOccurs=\"0\" />\n"
+"      <xsd:element name=\"inbodydescription\" type=\"descriptionType\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"location\" type=\"locationType\" />\n"
 "      <xsd:element name=\"references\" type=\"referenceType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"referencedby\" type=\"referenceType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "    </xsd:sequence>\n"
 "    <xsd:attribute name=\"kind\" type=\"DoxMemberKind\" />\n"
-"    <xsd:attribute name=\"id\" />\n"
+"    <xsd:attribute name=\"id\" type=\"xsd:string\" />\n"
 "    <xsd:attribute name=\"prot\" type=\"DoxProtectionKind\" />\n"
 "    <xsd:attribute name=\"static\" type=\"DoxBool\" />\n"
 "    <xsd:attribute name=\"const\" type=\"DoxBool\" />\n"
@@ -118,10 +145,13 @@
 "    <xsd:attribute name=\"virt\" type=\"DoxVirtualKind\" />\n"
 "    <xsd:attribute name=\"volatile\" type=\"DoxBool\" />\n"
 "    <xsd:attribute name=\"mutable\" type=\"DoxBool\" />\n"
+"    <xsd:attribute name=\"readable\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"writable\" type=\"DoxBool\" use=\"optional\"/>\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"descriptionType\" mixed=\"true\">\n"
 "    <xsd:sequence>\n"
+"      <xsd:element name=\"title\" type=\"xsd:string\" minOccurs=\"0\"/>	    \n"
 "      <xsd:element name=\"para\" type=\"docParaType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"sect1\" type=\"docSect1Type\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"internal\" type=\"docInternalType\" minOccurs=\"0\" />\n"
@@ -131,11 +161,11 @@
 "  <xsd:complexType name=\"enumvalueType\" mixed=\"true\">\n"
 "    <xsd:sequence>\n"
 "      <xsd:element name=\"name\" />\n"
+"      <xsd:element name=\"initializer\" type=\"linkedTextType\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"briefdescription\" type=\"descriptionType\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"detaileddescription\" type=\"descriptionType\" minOccurs=\"0\" />\n"
-"      <xsd:element name=\"initializer\" type=\"linkedTextType\" minOccurs=\"0\" />\n"
 "    </xsd:sequence>\n"
-"    <xsd:attribute name=\"id\" />\n"
+"    <xsd:attribute name=\"id\" type=\"xsd:string\" />\n"
 "    <xsd:attribute name=\"prot\" type=\"DoxProtectionKind\" />\n"
 "  </xsd:complexType>\n"
 "\n"
@@ -174,25 +204,25 @@
 "      <xsd:element name=\"link\" type=\"linkType\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"childnode\" type=\"childnodeType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "    </xsd:sequence>\n"
-"    <xsd:attribute name=\"id\" />\n"
+"    <xsd:attribute name=\"id\" type=\"xsd:string\" />\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"childnodeType\">\n"
 "    <xsd:sequence>\n"
 "      <xsd:element name=\"edgelabel\" minOccurs=\"0\" maxOccurs=\"unbounded\"/>\n"
 "    </xsd:sequence>\n"
-"    <xsd:attribute name=\"refid\" />\n"
+"    <xsd:attribute name=\"refid\" type=\"xsd:string\" />\n"
 "    <xsd:attribute name=\"relation\" type=\"DoxGraphRelation\" />\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"linkType\">\n"
-"    <xsd:attribute name=\"refid\" />\n"
-"    <xsd:attribute name=\"external\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"refid\" type=\"xsd:string\" />\n"
+"    <xsd:attribute name=\"external\" type=\"xsd:string\" use=\"optional\"/>\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"listingType\">\n"
 "    <xsd:sequence>\n"
-"      <xsd:element name=\"codeline\" type=\"codelineType\" maxOccurs=\"unbounded\" />\n"
+"      <xsd:element name=\"codeline\" type=\"codelineType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "    </xsd:sequence>\n"
 "  </xsd:complexType>\n"
 "\n"
@@ -201,9 +231,9 @@
 "      <xsd:element name=\"highlight\" type=\"highlightType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "    </xsd:sequence>\n"
 "    <xsd:attribute name=\"lineno\" type=\"xsd:integer\" />\n"
-"    <xsd:attribute name=\"refid\" />\n"
+"    <xsd:attribute name=\"refid\" type=\"xsd:string\" />\n"
 "    <xsd:attribute name=\"refkind\" type=\"DoxRefKind\" />\n"
-"    <xsd:attribute name=\"external\" />\n"
+"    <xsd:attribute name=\"external\" type=\"DoxBool\" />\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"highlightType\" mixed=\"true\">\n"
@@ -215,15 +245,16 @@
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"referenceType\" mixed=\"true\">\n"
-"    <xsd:attribute name=\"refid\" />\n"
-"    <xsd:attribute name=\"compoundref\" use=\"optional\" />\n"
+"    <xsd:attribute name=\"refid\" type=\"xsd:string\" />\n"
+"    <xsd:attribute name=\"compoundref\" type=\"xsd:string\" use=\"optional\" />\n"
 "    <xsd:attribute name=\"startline\" type=\"xsd:integer\" />\n"
 "    <xsd:attribute name=\"endline\" type=\"xsd:integer\" />\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"locationType\">\n"
-"    <xsd:attribute name=\"file\" />\n"
+"    <xsd:attribute name=\"file\" type=\"xsd:string\" />\n"
 "    <xsd:attribute name=\"line\" type=\"xsd:integer\" />\n"
+"    <xsd:attribute name=\"bodyfile\" type=\"xsd:string\" />\n"
 "    <xsd:attribute name=\"bodystart\" type=\"xsd:integer\" />\n"
 "    <xsd:attribute name=\"bodyend\" type=\"xsd:integer\" />\n"
 "  </xsd:complexType>\n"
@@ -235,7 +266,7 @@
 "      <xsd:element name=\"sect2\" type=\"docSect2Type\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"internal\" type=\"docInternalS1Type\" minOccurs=\"0\" />\n"
 "    </xsd:sequence>\n"
-"    <xsd:attribute name=\"id\" />\n"
+"    <xsd:attribute name=\"id\" type=\"xsd:string\" />\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"docSect2Type\" mixed=\"true\">\n"
@@ -245,7 +276,7 @@
 "      <xsd:element name=\"sect3\" type=\"docSect3Type\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"internal\" type=\"docInternalS2Type\" minOccurs=\"0\" />\n"
 "    </xsd:sequence>\n"
-"    <xsd:attribute name=\"id\" />\n"
+"    <xsd:attribute name=\"id\" type=\"xsd:string\" />\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"docSect3Type\" mixed=\"true\">\n"
@@ -255,7 +286,7 @@
 "      <xsd:element name=\"sect4\" type=\"docSect4Type\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"internal\" type=\"docInternalS3Type\" minOccurs=\"0\" />\n"
 "    </xsd:sequence>\n"
-"    <xsd:attribute name=\"id\" />\n"
+"    <xsd:attribute name=\"id\" type=\"xsd:string\" />\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"docSect4Type\" mixed=\"true\">\n"
@@ -264,7 +295,7 @@
 "      <xsd:element name=\"para\" type=\"docParaType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"internal\" type=\"docInternalS4Type\" minOccurs=\"0\" />\n"
 "    </xsd:sequence>\n"
-"    <xsd:attribute name=\"id\" />\n"
+"    <xsd:attribute name=\"id\" type=\"xsd:string\" />\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"docInternalType\" mixed=\"true\">\n"
@@ -320,6 +351,12 @@
 "      <xsd:element name=\"copy\" type=\"docEmptyType\" />\n"
 "      <xsd:element name=\"trademark\" type=\"docEmptyType\" />\n"
 "      <xsd:element name=\"registered\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"lsquo\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"rsquo\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"ldquo\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"rdquo\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"ndash\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"mdash\" type=\"docEmptyType\" />\n"
 "      <xsd:element name=\"umlaut\" type=\"docCharType\" />\n"
 "      <xsd:element name=\"acute\" type=\"docCharType\" />\n"
 "      <xsd:element name=\"grave\" type=\"docCharType\" />\n"
@@ -377,11 +414,11 @@
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"docAnchorType\" mixed=\"true\">\n"
-"    <xsd:attribute name=\"id\" />\n"
+"    <xsd:attribute name=\"id\" type=\"xsd:string\" />\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"docFormulaType\" mixed=\"true\">\n"
-"    <xsd:attribute name=\"id\" />\n"
+"    <xsd:attribute name=\"id\" type=\"xsd:string\" />\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"docIndexEntryType\">\n"
@@ -432,9 +469,9 @@
 "\n"
 "  <xsd:complexType name=\"docRefTextType\" mixed=\"true\">\n"
 "    <xsd:group ref=\"docTitleCmdGroup\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
-"    <xsd:attribute name=\"refid\" />\n"
-"    <xsd:attribute name=\"kindref\" />\n"
-"    <xsd:attribute name=\"external\" />\n"
+"    <xsd:attribute name=\"refid\" type=\"xsd:string\" />\n"
+"    <xsd:attribute name=\"kindref\" type=\"DoxRefKind\" />\n"
+"    <xsd:attribute name=\"external\" type=\"xsd:string\" />\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"docTableType\">\n"
@@ -483,7 +520,7 @@
 "\n"
 "  <xsd:complexType name=\"docTocItemType\" mixed=\"true\">\n"
 "    <xsd:group ref=\"docTitleCmdGroup\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
-"    <xsd:attribute name=\"id\" /> \n"
+"    <xsd:attribute name=\"id\" type=\"xsd:string\" /> \n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"docTocListType\">\n"
@@ -499,26 +536,39 @@
 "    <xsd:attribute name=\"langid\" type=\"xsd:string\" /> \n"
 "  </xsd:complexType>\n"
 "\n"
-"  <xsd:group name=\"docParamListGroup\">\n"
-"    <xsd:sequence>\n"
-"      <xsd:element name=\"parametername\" type=\"xsd:string\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
-"      <xsd:element name=\"parameterdescription\" type=\"descriptionType\" />\n"
-"    </xsd:sequence>\n"
-"  </xsd:group>\n"
-"\n"
 "  <xsd:complexType name=\"docParamListType\">\n"
 "    <xsd:sequence>\n"
-"      <xsd:group ref=\"docParamListGroup\" maxOccurs=\"unbounded\" />\n"
+"      <xsd:element name=\"parameteritem\" type=\"docParamListItem\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "    </xsd:sequence>\n"
 "    <xsd:attribute name=\"kind\" type=\"DoxParamListKind\" /> \n"
 "  </xsd:complexType>\n"
 "\n"
+"  <xsd:complexType name=\"docParamListItem\">\n"
+"    <xsd:sequence>\n"
+"      <xsd:element name=\"parameternamelist\" type=\"docParamNameList\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
+"      <xsd:element name=\"parameterdescription\" type=\"descriptionType\" />\n"
+"    </xsd:sequence>\n"
+"  </xsd:complexType>\n"
+"\n"
+"  <xsd:complexType name=\"docParamNameList\">\n"
+"    <xsd:sequence>\n"
+"      <xsd:element name=\"parametername\" type=\"docParamName\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
+"    </xsd:sequence>\n"
+"  </xsd:complexType>\n"
+"\n"
+"  <xsd:complexType name=\"docParamName\" mixed=\"true\">\n"
+"    <xsd:sequence>\n"
+"      <xsd:element name=\"ref\" type=\"refTextType\" minOccurs=\"0\" maxOccurs=\"1\" />\n"
+"    </xsd:sequence>\n"
+"    <xsd:attribute name=\"direction\" type=\"DoxParamDir\" use=\"optional\" />\n"
+"  </xsd:complexType>\n"
+"\n"
 "  <xsd:complexType name=\"docXRefSectType\">\n"
 "    <xsd:sequence>\n"
 "      <xsd:element name=\"xreftitle\" type=\"xsd:string\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"xrefdescription\" type=\"descriptionType\" />\n"
 "    </xsd:sequence>\n"
-"    <xsd:attribute name=\"id\" /> \n"
+"    <xsd:attribute name=\"id\" type=\"xsd:string\" /> \n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"docCopyType\">\n"
@@ -527,7 +577,7 @@
 "      <xsd:element name=\"sect1\" type=\"docSect1Type\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"internal\" type=\"docInternalType\" minOccurs=\"0\" />\n"
 "    </xsd:sequence>\n"
-"    <xsd:attribute name=\"link\" /> \n"
+"    <xsd:attribute name=\"link\" type=\"xsd:string\" /> \n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"docCharType\">\n"
@@ -603,11 +653,15 @@
 "      <xsd:enumeration value=\"struct\" />\n"
 "      <xsd:enumeration value=\"union\" />\n"
 "      <xsd:enumeration value=\"interface\" />\n"
+"      <xsd:enumeration value=\"protocol\" />\n"
+"      <xsd:enumeration value=\"category\" />\n"
 "      <xsd:enumeration value=\"exception\" />\n"
 "      <xsd:enumeration value=\"file\" />\n"
 "      <xsd:enumeration value=\"namespace\" />\n"
 "      <xsd:enumeration value=\"group\" />\n"
 "      <xsd:enumeration value=\"page\" />\n"
+"      <xsd:enumeration value=\"example\" />\n"
+"      <xsd:enumeration value=\"dir\" />\n"
 "    </xsd:restriction>\n"
 "  </xsd:simpleType>\n"
 "\n"
@@ -630,6 +684,11 @@
 "      <xsd:enumeration value=\"protected-slot\" />\n"
 "      <xsd:enumeration value=\"protected-static-func\" />\n"
 "      <xsd:enumeration value=\"protected-static-attrib\" />\n"
+"      <xsd:enumeration value=\"package-type\" />\n"
+"      <xsd:enumeration value=\"package-func\" />\n"
+"      <xsd:enumeration value=\"package-attrib\" />\n"
+"      <xsd:enumeration value=\"package-static-func\" />\n"
+"      <xsd:enumeration value=\"package-static-attrib\" />\n"
 "      <xsd:enumeration value=\"private-type\" />\n"
 "      <xsd:enumeration value=\"private-func\" />\n"
 "      <xsd:enumeration value=\"private-attrib\" />\n"
@@ -709,5 +768,13 @@
 "    </xsd:restriction>\n"
 "  </xsd:simpleType>\n"
 "\n"
+"  <xsd:simpleType name=\"DoxParamDir\">\n"
+"    <xsd:restriction base=\"xsd:string\">\n"
+"      <xsd:enumeration value=\"in\"/>\n"
+"      <xsd:enumeration value=\"out\"/>\n"
+"      <xsd:enumeration value=\"inout\"/>\n"
+"    </xsd:restriction>\n"
+"  </xsd:simpleType>\n"
+"\n"
 "</xsd:schema>\n"
 "\n"
