@@ -24,7 +24,6 @@
 #include "util.h"
 #include "config.h"
 #include "language.h"
-#include "scanner.h"
 #include "defargs.h"
 #include "docparser.h"
 #include "debug.h"
@@ -200,7 +199,7 @@ static bool convertMapFile(QTextStream &t,const char *mapName,
   return TRUE;
 }
 
-static QArray<int> * s_newNumber = new QArray<int>();
+static QArray<int> s_newNumber;
 static int s_max_newNumber=0;
 
 inline int reNumberNode(int number, bool doReNumbering)
@@ -211,7 +210,7 @@ inline int reNumberNode(int number, bool doReNumbering)
   } 
   else 
   {
-    int s = s_newNumber->size();
+    int s = s_newNumber.size();
     if (number>=s) 
     {
       int ns=0;
@@ -220,17 +219,17 @@ inline int reNumberNode(int number, bool doReNumbering)
       {
         ns = number * 3 / 2 + 5;
       }
-      s_newNumber->resize(ns);
+      s_newNumber.resize(ns);
       for (int i=s;i<ns;i++) // clear new part of the array
       {
-        s_newNumber->at(i)=0;
+        s_newNumber.at(i)=0;
       }
     }
-    int i = s_newNumber->at(number);
+    int i = s_newNumber.at(number);
     if (i == 0) // not yet mapped
     {
       i = ++s_max_newNumber; // start from 1
-      s_newNumber->at(number) = i;
+      s_newNumber.at(number) = i;
     }
     return i;
   }
@@ -239,7 +238,7 @@ inline int reNumberNode(int number, bool doReNumbering)
 static void resetReNumbering() 
 {
   s_max_newNumber=0;
-  s_newNumber->resize(s_max_newNumber);
+  s_newNumber.resize(s_max_newNumber);
 }
 
 static bool readBoundingBoxDot(const char *fileName,int *width,int *height)
@@ -288,6 +287,7 @@ static bool readBoundingBoxEPS(const char *fileName,int *width,int *height)
   return FALSE;
 }
 
+#if 0
 /*! returns TRUE if class cd is a leaf (i.e. has no visible children)
  */
 static bool isLeaf(ClassDef *cd)
@@ -312,6 +312,7 @@ static bool isLeaf(ClassDef *cd)
   }
   return TRUE;
 }
+#endif
 
 // since dot silently reproduces the input file when it does not
 // support the PNG format, we need to check the result.
@@ -566,10 +567,12 @@ static QCString convertLabel(const QCString &l)
     switch(c)
     {
       case '\\': result+="\\\\"; break;
-      case '<': result+="\\<"; break;
-      case '>': result+="\\>"; break;
-      case '|': result+="\\|"; break;
-      default: result+=c; break;
+      case '\n': result+="\\n"; break;
+      case '<':  result+="\\<"; break;
+      case '>':  result+="\\>"; break;
+      case '|':  result+="\\|"; break;
+      case '"':  result+="\\\""; break;
+      default:   result+=c; break;
     }
   }
   return result;
@@ -712,7 +715,7 @@ void DotNode::writeArrow(QTextStream &t,
     << "\",fontsize=10,style=\"" << edgeStyleMap[ei->m_style] << "\"";
   if (!ei->m_label.isEmpty())
   {
-    t << ",label=\"" << ei->m_label << "\"";
+    t << ",label=\"" << convertLabel(ei->m_label) << "\"";
   }
   if (Config_getBool("UML_LOOK") &&
       arrowStyle[ei->m_color] && 
@@ -1125,14 +1128,6 @@ void DotGfxHierarchyTable::writeGraph(QTextStream &out,const char *path)
         return;
       }
       
-      //QCString dotArgs(maxCmdLine);
-      //dotArgs.sprintf("\"%s\" -T%s -o \"%s\" -Timap -o \"%s\"",
-      //    dotName.data(), imgExt.data(), imgName.data(), mapName.data());
-      //if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs)!=0)
-      //{
-      //  err("Problems running dot. Check your installation!\n");
-      //  return;
-      //}
       checkDotResult(imgName);
       if (Config_getBool("DOT_CLEANUP")) thisDir.remove(dotName);
     }
@@ -1158,7 +1153,7 @@ void DotGfxHierarchyTable::addHierarchy(DotNode *n,ClassDef *cd,bool hideSuper)
   for ( ; (bcd=bcli.current()) ; ++bcli )
   {
     ClassDef *bClass=bcd->classDef; 
-    //printf("  Trying super class=`%s' usedNodes=%d\n",bClass->name().data(),m_usedNodes->count());
+    //printf("  Trying sub class=`%s' usedNodes=%d\n",bClass->name().data(),m_usedNodes->count());
     if (bClass->isVisibleInHierarchy() && hasVisibleRoot(bClass->baseClasses()))
     {
       DotNode *bn;
@@ -1185,8 +1180,10 @@ void DotGfxHierarchyTable::addHierarchy(DotNode *n,ClassDef *cd,bool hideSuper)
       else 
       {
         QCString tmp_url="";
-        if (bClass->isLinkable()) 
+        if (bClass->isLinkable() && !bClass->isHidden())
+        {
           tmp_url=bClass->getReference()+"$"+bClass->getOutputFileBase();
+        }
         bn = new DotNode(m_curNodeNumber++,
              bClass->displayName(),
              tmp_url.data()
@@ -1225,8 +1222,10 @@ void DotGfxHierarchyTable::addClassList(ClassSDict *cl)
        ) // root node in the forest
     {
       QCString tmp_url="";
-      if (cd->isLinkable()) 
+      if (cd->isLinkable() && !cd->isHidden()) 
+      {
         tmp_url=cd->getReference()+"$"+cd->getOutputFileBase();
+      }
       //printf("Inserting root class %s\n",cd->name().data());
       DotNode *n = new DotNode(m_curNodeNumber++,
           cd->displayName(),
@@ -1360,7 +1359,7 @@ void DotClassGraph::addClass(ClassDef *cd,DotNode *n,int prot,
     QCString displayName=className;
     if (Config_getBool("HIDE_SCOPE_NAMES")) displayName=stripScope(displayName);
     QCString tmp_url;
-    if (cd->isLinkable()) 
+    if (cd->isLinkable() && !cd->isHidden()) 
     {
       tmp_url=cd->getReference()+"$"+cd->getOutputFileBase();
     }
@@ -1383,7 +1382,8 @@ void DotClassGraph::addClass(ClassDef *cd,DotNode *n,int prot,
       n->addParent(bn);
     }
     m_usedNodes->insert(className,bn);
-    //printf(" add new child node `%s' to %s\n",className.data(),n->m_label.data());
+    //printf(" add new child node `%s' to %s hidden=%d url=%s\n",
+    //    className.data(),n->m_label.data(),cd->isHidden(),tmp_url.data());
     
     // we use <=, i.s.o < to cause one more level than intended which is used to 
     // detect truncated nodes
@@ -1445,7 +1445,7 @@ void DotClassGraph::buildGraph(ClassDef *cd,DotNode *n,int distance,bool base)
           }
           else
           {
-            label+=QCString("\\n")+s;
+            label+=QCString("\n")+s;
           }
         }
         addClass(ucd->classDef,n,EdgeInfo::Purple,label,distance,0,
@@ -1499,7 +1499,10 @@ DotClassGraph::DotClassGraph(ClassDef *cd,DotNode::GraphType t,int maxRecursionD
   m_maxDistance = 0;
   m_recDepth = maxRecursionDepth;
   QCString tmp_url="";
-  if (cd->isLinkable()) tmp_url=cd->getReference()+"$"+cd->getOutputFileBase();
+  if (cd->isLinkable() && !cd->isHidden()) 
+  {
+    tmp_url=cd->getReference()+"$"+cd->getOutputFileBase();
+  }
   QCString className = cd->displayName();
   //if (cd->templateArguments())
   //{
@@ -1688,15 +1691,6 @@ static bool findMaximalDotGraph(DotNode *root,
       return FALSE;
     }
     
-    //QCString dotArgs(maxCmdLine);
-    //// create annotated dot file
-    //dotArgs.sprintf("-Tdot \"%s.dot\" -o \"%s_tmp.dot\"",baseName.data(),baseName.data());
-    //if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs)!=0)
-    // {
-    //  err("Problems running dot. Check your installation!\n");
-    //  return FALSE;
-    //}
-
     // extract bounding box from the result
     readBoundingBoxDot(baseName+"_tmp.dot",&width,&height);
     width  = width *96/72; // 96 pixels/inch, 72 points/inch
@@ -1841,20 +1835,6 @@ QCString DotClassGraph::writeGraph(QTextStream &out,
         return baseName;
       }
 
-      //dotArgs.sprintf("\"%s.dot\" -T%s -o \"%s\"",
-      //    baseName.data(),imgExt.data(),imgName.data());
-      //if (generateImageMap)
-      //{
-      //  // run dot also to create an image map
-      //  dotArgs+=QCString(maxCmdLine).sprintf(" -Timap -o \"%s.map\"",
-      //      baseName.data());
-      //}
-      //if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs)!=0)
-      //{
-      //  err("Error: Problems running dot. Check your installation!\n");
-      //  QDir::setCurrent(oldDir);
-      //  return baseName;
-      //}
       checkDotResult(imgName);
     }
     else if (format==EPS) // run dot to create a .eps image
@@ -1867,14 +1847,6 @@ QCString DotClassGraph::writeGraph(QTextStream &out,
         return baseName;
       }
       
-      //QCString dotArgs(maxCmdLine);
-      //dotArgs.sprintf("-Tps \"%s.dot\" -o \"%s.eps\"",baseName.data(),baseName.data());
-      //if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs)!=0)
-      //{
-      //  err("Error: Problems running dot. Check your installation!\n");
-      //  QDir::setCurrent(oldDir);
-      //  return baseName;
-      //}
       if (Config_getBool("USE_PDFLATEX"))
       {
         QCString epstopdfArgs(maxCmdLine);
@@ -1986,7 +1958,7 @@ void DotInclDepGraph::buildGraph(DotNode *n,FileDef *fd,int distance)
     if (bfd)
     {
       in  = bfd->absFilePath();  
-      doc = bfd->isLinkable();
+      doc = bfd->isLinkable() && bfd->isHidden();
       src = bfd->generateSourceFile();
     }
     if (doc || src || !Config_getBool("HIDE_UNDOC_RELATIONS"))
@@ -2121,20 +2093,6 @@ QCString DotInclDepGraph::writeGraph(QTextStream &out,
         QDir::setCurrent(oldDir);
         return baseName;
       }
-      //dotArgs.sprintf("\"%s.dot\" -T%s -o \"%s\"",
-      //    baseName.data(),imgExt.data(),imgName.data());
-      //if (generateImageMap)
-      //{
-      //  // run dot also to create an image map
-      //  dotArgs+=QCString(maxCmdLine).sprintf(" -Timap -o \"%s.map\"",
-      //      baseName.data());
-      //}
-      //if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs)!=0)
-      //{
-      //  err("Problems running dot. Check your installation!\n");
-      //  QDir::setCurrent(oldDir);
-      //  return baseName;
-      //}
       checkDotResult(imgName);
     }
     else if (format==EPS)
@@ -2147,15 +2105,6 @@ QCString DotInclDepGraph::writeGraph(QTextStream &out,
         QDir::setCurrent(oldDir);
         return baseName;
       }
-      //QCString dotArgs(maxCmdLine);
-      //dotArgs.sprintf("-Tps \"%s.dot\" -o \"%s.eps\"",
-      //    baseName.data(),baseName.data());
-      //if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs)!=0)
-      //{
-      //  err("Problems running dot. Check your installation!\n");
-      //  QDir::setCurrent(oldDir);
-      //  return baseName;
-      //}
       if (Config_getBool("USE_PDFLATEX"))
       {
         QCString epstopdfArgs(maxCmdLine);
@@ -2322,20 +2271,6 @@ QCString DotCallGraph::writeGraph(QTextStream &out, GraphOutputFormat format,
         QDir::setCurrent(oldDir);
         return baseName;
       }
-      //dotArgs.sprintf("\"%s.dot\" -T%s -o \"%s\"",
-      //    baseName.data(),imgExt.data(),imgName.data());
-      //if (generateImageMap)
-      //{
-      //  // run dot also to create an image map
-      //  dotArgs+=QCString(maxCmdLine).sprintf(" -Timap -o \"%s.map\"",
-      //      baseName.data());
-      //}
-      //if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs)!=0)
-      //{
-      //  err("Problems running dot. Check your installation!\n");
-      //  QDir::setCurrent(oldDir);
-      //  return baseName;
-      //}
       checkDotResult(imgName);
     }
     else if (format==EPS)
@@ -2348,15 +2283,6 @@ QCString DotCallGraph::writeGraph(QTextStream &out, GraphOutputFormat format,
         QDir::setCurrent(oldDir);
         return baseName;
       }
-      //QCString dotArgs(maxCmdLine);
-      //dotArgs.sprintf("-Tps \"%s.dot\" -o \"%s.eps\"",
-      //    baseName.data(),baseName.data());
-      //if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs)!=0)
-      //{
-      //  err("Problems running dot. Check your installation!\n");
-      //  QDir::setCurrent(oldDir);
-      //  return baseName;
-      //}
       if (Config_getBool("USE_PDFLATEX"))
       {
         QCString epstopdfArgs(maxCmdLine);
@@ -2529,20 +2455,6 @@ QCString DotDirDeps::writeGraph(QTextStream &out,
         QDir::setCurrent(oldDir);
         return baseName;
       }
-      //dotArgs.sprintf("\"%s.dot\" -T%s -o \"%s\"",
-      //    baseName.data(),imgExt.data(),imgName.data());
-      //if (generateImageMap)
-      //{
-      //  // run dot also to create an image map
-      //  dotArgs+=QCString(maxCmdLine).sprintf(" -Timap -o \"%s.map\"",
-      //      baseName.data());
-      //}
-      //if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs)!=0)
-      //{
-      //  err("Problems running dot. Check your installation!\n");
-      //  QDir::setCurrent(oldDir);
-      //  return baseName;
-      //}
       checkDotResult(imgName);
     }
     else if (format==EPS)
@@ -2555,15 +2467,6 @@ QCString DotDirDeps::writeGraph(QTextStream &out,
         QDir::setCurrent(oldDir);
         return baseName;
       }
-      //QCString dotArgs(maxCmdLine);
-      //dotArgs.sprintf("-Tps \"%s.dot\" -o \"%s.eps\"",
-      //    baseName.data(),baseName.data());
-      //if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs)!=0)
-      //{
-      //  err("Problems running dot. Check your installation!\n");
-      //  QDir::setCurrent(oldDir);
-      //  return baseName;
-      //}
       if (Config_getBool("USE_PDFLATEX"))
       {
         QCString epstopdfArgs(maxCmdLine);
@@ -2689,14 +2592,6 @@ void generateGraphLegend(const char *path)
       QDir::setCurrent(oldDir);
       return;
   }
-  //QCString dotArgs(maxCmdLine);
-  //dotArgs.sprintf("-T%s graph_legend.dot -o %s",imgExt.data(),imgName.data());
-  //if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs)!=0)
-  //{
-  //    err("Problems running dot. Check your installation!\n");
-  //    QDir::setCurrent(oldDir);
-  //    return;
-  //}
   checkDotResult(imgName);
   QDir::setCurrent(oldDir);
 }
@@ -2742,24 +2637,6 @@ void writeDotGraphFromFile(const char *inFile,const char *outDir,
     QDir::setCurrent(oldDir);
     return;
   }
-  //QCString dotArgs(maxCmdLine);
-  //if (format==BITMAP)
-  //{
-  //  dotArgs.sprintf("-T%s \"%s\" -o \"%s\"",
-  //      imgExt.data(),
-  //      inFile,
-  //      imgName.data());
-  //}
-  //else // format==EPS
-  //{
-  //  dotArgs.sprintf("-Tps \"%s\" -o \"%s.eps\"",inFile,outFile);
-  //}
-  //QCString dotExe = Config_getString("DOT_PATH")+"dot";
-  ////printf("Running: %s %s\n",dotExe.data(),dotArgs.data());
-  //if (iSystem(dotExe,dotArgs)!=0)
-  //{
-  //  err("Problems running dot. Check your installation!\n");
-  //}
   // Added by Nils Strom
   if ( (format==EPS) && (Config_getBool("USE_PDFLATEX")) )
   {
@@ -2804,16 +2681,6 @@ QString getDotImageMapFromFile(const QString& inFile, const QString& outDir,
     return "";
   }
   
-  //QCString dotArgs(maxCmdLine);
-  //dotArgs.sprintf("-Timap \"%s\" -o \"%s\"", inFile.data(), outFile.data());
-  //QCString dotExe = Config_getString("DOT_PATH") + "dot";
-  ////printf("Running: %s %s\n",dotExe.data(),dotArgs.data());
-  //if (iSystem(dotExe,dotArgs)!=0)
-  //{
-  //  err("Problems running dot. Check your installation!\n");
-  //  QDir::setCurrent(oldDir);
-  //  return "";
-  //}
   QString result;
   QTextOStream tmpout(&result);
   convertMapFile(tmpout, outFile, relPath ,TRUE);
@@ -3090,21 +2957,6 @@ QCString DotGroupCollaboration::writeGraph( QTextStream &t, GraphOutputFormat fo
       QDir::setCurrent(oldDir);
       return baseName;
     }
-    //dotArgs.sprintf("\"%s.dot\" -T%s -o \"%s\"",
-    //    baseName.data(), imgExt.data(), imgName.data());
-    // 
-    //if (writeImageMap)
-    //{
-    //  // run dot also to create an image map
-    //  dotArgs+=" -Timap -o \""+mapName+"\"";
-    //}
-    //
-    //if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs)!=0)
-    //{
-    //  err("Error: Problems running dot. Check your installation!\n");
-    //  QDir::setCurrent(oldDir);
-    //  return baseName;
-    //}
 
     if (writeImageMap)
     {
@@ -3127,15 +2979,7 @@ QCString DotGroupCollaboration::writeGraph( QTextStream &t, GraphOutputFormat fo
       QDir::setCurrent(oldDir);
       return baseName;
     }
-    //QCString dotArgs(maxCmdLine);
-    //dotArgs.sprintf("-Tps \"%s.dot\" -o \"%s.eps\"",
-    //    baseName.data(),baseName.data());
-    //if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs)!=0)
-    //{
-    //  err("Error: Problems running dot. Check your installation!\n");
-    //  QDir::setCurrent(oldDir);
-    //  return baseName;
-    //}
+
     if (Config_getBool("USE_PDFLATEX"))
     {
       QCString epstopdfArgs(maxCmdLine);
@@ -3216,7 +3060,7 @@ void DotGroupCollaboration::Edge::write( QTextStream &t, int& )
     for( lli.toFirst(); (link=lli.current()); ++lli)
     {
       if (first) first=FALSE; else t << "\\n"; 
-      t << link->label;
+      t << convertLabel(link->label);
     }
     t << "\"";
 
