@@ -2,7 +2,7 @@
  *
  * $Id: entry.cpp,v 1.29 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -38,11 +38,11 @@ Entry::Entry()
   argList->setAutoDelete(TRUE);
   //printf("Entry::Entry() tArgList=0\n");
   tArgLists = 0;
-  //mtArgList = 0;
   mGrpId = -1;
   tagInfo = 0;
   sli = 0;
   relatesDup = FALSE;
+  hidden = FALSE;
   groupDocType = GROUPDOC_NORMAL;
   reset();
 }
@@ -71,6 +71,8 @@ Entry::Entry(const Entry &e)
   docFile     = e.docFile.copy();
   relates     = e.relates.copy();
   relatesDup  = e.relatesDup;
+  read        = e.read.copy();
+  write       = e.write.copy();
   brief       = e.brief.copy();
   briefLine   = e.briefLine;
   briefFile   = e.briefFile.copy();
@@ -88,10 +90,8 @@ Entry::Entry(const Entry &e)
   initLines   = e.initLines;
   callGraph   = e.callGraph;
   objc        = e.objc;
-  //todoId      = e.todoId;
-  //testId      = e.testId;
-  //bugId       = e.bugId;
   tagInfo     = e.tagInfo;
+  hidden      = e.hidden;
   sublist     = new QList<Entry>;
   sublist->setAutoDelete(TRUE);
   extends     = new QList<BaseInfo>;
@@ -152,19 +152,6 @@ Entry::Entry(const Entry &e)
     tArgLists = copyArgumentLists(e.tArgLists);
   }
 
-  // deep copy template argument list
-  //if (e.mtArgList)
-  //{
-  //  mtArgList = new ArgumentList;
-  //  mtArgList->setAutoDelete(TRUE);
-  //  //printf("Entry::Entry(copy) new tArgList=%p\n",tArgList);
-  //  QListIterator<Argument> mtali(*e.mtArgList);
-  //  for (;(a=mtali.current());++mtali)
-  //  {
-  //    mtArgList->append(new Argument(*a));
-  //    //printf("appending argument %s %s\n",a->type.data(),a->name.data());
-  //  }
-  //}
   if (e.sli)
   {
     sli = new QList<ListItemInfo>;
@@ -200,22 +187,12 @@ Entry::~Entry()
 
 void Entry::addSubEntry(Entry *current)
 {
-  //printf("Entry %d with name %s type 0x%x added\n",
-  //    current->num,current->name.data(),current->section);
+  //printf("Entry %d with name %s type 0x%x added to %s type 0x%x\n",
+  //    current->num,current->name.data(),current->section,
+  //    name.data(),section);
   //printf("Entry::addSubEntry(%s) %p\n",current->name.data(),current->tArgList);
   current->parent=this;
   sublist->append(current);  
-  
-  //if (current->tArgList)
-  //{
-  //  Argument * a=current->tArgList->first();
-  //  while (a)
-  //  {
-  //    printf("type=%s name=%s\n",a->type.data(),a->name.data());
-  //    a=current->tArgList->next();
-  //  }
-  //}
-
 }
 
 void Entry::reset()
@@ -226,7 +203,6 @@ void Entry::reset()
   bitfields.resize(0);
   exception.resize(0);
   program.resize(0);
-  //body.resize(0);
   includeFile.resize(0);
   includeName.resize(0);
   doc.resize(0);
@@ -242,8 +218,6 @@ void Entry::reset()
   inbodyLine=-1;
   inside.resize(0);
   fileName.resize(0);
-  //scopeSpec.resize(0);
-  //memberSpec.resize(0);
   initializer.resize(0);
   initLines = -1;
   startLine = 1;
@@ -251,9 +225,6 @@ void Entry::reset()
   endBodyLine = -1;
   mGrpId = -1;
   callGraph = FALSE;
-  //todoId = 0;
-  //testId = 0;
-  //bugId = 0;
   section = EMPTY_SEC;
   mtype   = Method;
   virt    = Normal;
@@ -262,6 +233,7 @@ void Entry::reset()
   explicitExternal = FALSE;
   memSpec  = 0;
   objc = FALSE;
+  hidden = FALSE;
   subGrouping = TRUE;
   protection = Public;
   groupDocType = GROUPDOC_NORMAL;
@@ -279,86 +251,7 @@ void Entry::reset()
 
 int Entry::getSize()
 {
-  int size=sizeof(Entry);
-  size+=type.length()+1;
-  size+=name.length()+1;
-  size+=args.length()+1;
-  size+=bitfields.length()+1;
-  size+=exception.length()+1;
-  size+=program.length()+1;
-  size+=includeFile.length()+1;
-  size+=includeName.length()+1;
-  size+=doc.length()+1;
-  size+=docFile.length()+1;
-  size+=relates.length()+1;
-  size+=brief.length()+1;
-  size+=briefFile.length()+1;
-  size+=inbodyDocs.length()+1;
-  size+=inbodyFile.length()+1;
-  size+=inside.length()+1;
-  size+=fileName.length()+1;
-  size+=initializer.length()+1;
-  BaseInfo *bi=extends->first();
-  while (bi)
-  {
-    size+=sizeof(QLNode);
-    size+=bi->name.length()+1+sizeof(bi->prot)+sizeof(bi->virt);
-    bi=extends->next(); 
-  }
-  Grouping *g=groups->first();
-  while (g)
-  {
-    size+=sizeof(QLNode);
-    size+=g->groupname.length()+1;
-    size+=sizeof(g->pri);
-    g=groups->next();
-  }
-  Entry *e=sublist->first();
-  while (e)
-  {
-    size+=e->getSize();
-    e=sublist->next();
-  }
-  Argument *a=argList->first();
-  while (a)
-  {
-    size+=sizeof(Argument);
-    size+=a->type.length()+1
-         +a->name.length()+1
-         +a->defval.length()+1;
-    a=argList->next();
-  }
-  if (tArgLists)
-  {
-    ArgumentList *al=tArgLists->first();
-    while (al)
-    {
-      size+=sizeof(ArgumentList);
-      a=al->first();
-      while (a)
-      {
-        size+=sizeof(Argument);
-        size+=a->type.length()+1
-          +a->name.length()+1
-          +a->defval.length()+1;
-        a=al->next();
-      }
-      al=tArgLists->next();
-    }
-  }
-  //if (mtArgList)
-  //{
-  //  a=mtArgList->first();
-  //  while (e)
-  //  {
-  //    size+=sizeof(Argument);
-  //    size+=a->type.length()+1
-  //      +a->name.length()+1
-  //      +a->defval.length()+1;
-  //    a=mtArgList->next();
-  //  }
-  //}
-  return size;
+  return sizeof(Entry);
 }
 
 /*! the argument list is documented if one of its
