@@ -87,6 +87,7 @@ struct Argument
   
   QCString attrib;   /*!< Argument's attribute (IDL only) */
   QCString type;     /*!< Argument's type */
+  QCString canType;  /*!< Cached value of canonical type (after type resolution). Empty initially. */
   QCString name;     /*!< Argument's name (may be empty) */
   QCString array;    /*!< Argument's array specifier (may be empty) */
   QCString defval;   /*!< Argument's default value (may be empty) */
@@ -309,6 +310,7 @@ class Entry
     TagInfo    *tagInfo;      //!< tag file info
     static int  num;          //!< counts the total number of entries
     bool        objc;         //!< Objective-C construct
+    bool        hidden;       //!< does this represent an entity this is hidden from the output
     enum 
     {
       GROUPDOC_NORMAL,        //!< defgroup
@@ -320,9 +322,9 @@ class Entry
     {
       switch( groupDocType ) 
       {
-        case GROUPDOC_NORMAL: return "\\defgroup"; break;
-        case GROUPDOC_ADD: return "\\addgroup"; break;
-        case GROUPDOC_WEAK: return "\\weakgroup"; break;
+        case GROUPDOC_NORMAL: return "\\defgroup";
+        case GROUPDOC_ADD: return "\\addgroup";
+        case GROUPDOC_WEAK: return "\\weakgroup";
         default: return "unknown group command";
       }
     }
@@ -334,9 +336,9 @@ class Entry
       }
       switch( groupDocType ) 
       {
-        case GROUPDOC_NORMAL: return Grouping::GROUPING_AUTO_DEF;  break;
-        case GROUPDOC_ADD:    return Grouping::GROUPING_AUTO_ADD;  break;
-        case GROUPDOC_WEAK:   return Grouping::GROUPING_AUTO_WEAK; break;
+        case GROUPDOC_NORMAL: return Grouping::GROUPING_AUTO_DEF;
+        case GROUPDOC_ADD:    return Grouping::GROUPING_AUTO_ADD;
+        case GROUPDOC_WEAK:   return Grouping::GROUPING_AUTO_WEAK;
         default: return Grouping::GROUPING_LOWEST;
       }
     }
