@@ -28,18 +28,18 @@
 #include "outputlist.h"
 #include "dot.h"
 #include "message.h"
-#include "code.h"
 #include "docparser.h"
 #include "ftvhelp.h"
 #include "searchindex.h"
-//#include "xml.h"
+#include "htags.h"
+#include "parserintf.h"
 
 #if defined(_MSC_VER) || defined(__BORLANDC__)
 #define popen _popen
 #define pclose _pclose
 #endif
 
-class DevNullCodeDocInterface : public BaseCodeDocInterface
+class DevNullCodeDocInterface : public CodeOutputInterface
 {
   public:
     virtual void codify(const char *) {}
@@ -97,6 +97,15 @@ FileDef::FileDef(const char *p,const char *nm,
   memberGroupSDict = new MemberGroupSDict;
   memberGroupSDict->setAutoDelete(TRUE);
   acquireFileVersion();
+
+  // members in the detailed part of the documentation
+  docDefineMembers.setInFile(TRUE);
+  docProtoMembers.setInFile(TRUE);
+  docTypedefMembers.setInFile(TRUE);
+  docEnumMembers.setInFile(TRUE);
+  docFuncMembers.setInFile(TRUE);
+  docVarMembers.setInFile(TRUE);
+
 }
 
 /*! destroy the file definition */
@@ -225,7 +234,7 @@ void FileDef::writeDocumentation(OutputList &ol)
   }
   QCString title = docname+versionTitle;
   QCString pageTitle=theTranslator->trFileReference(docname);
-  startFile(ol,getOutputFileBase(),name(),pageTitle);
+  startFile(ol,getOutputFileBase(),name(),pageTitle,HLI_FileVisible);
 
   if (Config_getBool("SHOW_DIRECTORIES") && getDirDef())
   {
@@ -574,6 +583,8 @@ void FileDef::writeMemberPages(OutputList &ol)
 
 void FileDef::writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const
 {
+  static bool createSubDirs=Config_getBool("CREATE_SUBDIRS");
+
   ol.writeString("      <div class=\"navtab\">\n");
   ol.writeString("        <table>\n");
 
@@ -595,6 +606,7 @@ void FileDef::writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const
           ol.writeString("<a class=\"qindex\" ");
         }
         ol.writeString("href=\"");
+        if (createSubDirs) ol.writeString("../../");
         ol.writeString(md->getOutputFileBase()+Doxygen::htmlFileExtension+"#"+md->anchor());
         ol.writeString("\">");
         ol.writeString(md->localName());
@@ -618,7 +630,7 @@ void FileDef::writeSource(OutputList &ol)
   }
   QCString pageTitle = theTranslator->trSourceFile(title);
   ol.disableAllBut(OutputGenerator::Html);
-  startFile(ol,getSourceFileBase(),0,pageTitle);
+  startFile(ol,getSourceFileBase(),0,pageTitle,HLI_FileVisible);
 
   if (Config_getBool("SHOW_DIRECTORIES") && getDirDef())
   {
@@ -641,9 +653,10 @@ void FileDef::writeSource(OutputList &ol)
     ol.endTextLink();
   }
 
-  initParseCodeContext();
+  ParserInterface *pIntf = Doxygen::parserManager->getParser(getDefFileExtension());
+  pIntf->resetCodeParserState();
   ol.startCodeFragment();
-  parseCode(ol,0,
+  pIntf->parseCode(ol,0,
             fileToString(absFilePath(),Config_getBool("FILTER_SOURCE_FILES")),
             FALSE,0,this
            );
@@ -655,7 +668,10 @@ void FileDef::writeSource(OutputList &ol)
 void FileDef::parseSource()
 {
   DevNullCodeDocInterface devNullIntf;
-  parseCode(devNullIntf,0,
+  ParserInterface *pIntf = Doxygen::parserManager->getParser(getDefFileExtension());
+  pIntf->resetCodeParserState();
+  pIntf->parseCode(
+            devNullIntf,0,
             fileToString(absFilePath(),Config_getBool("FILTER_SOURCE_FILES")),
             FALSE,0,this
            );
@@ -674,11 +690,17 @@ void FileDef::addMembersToMemberGroup()
 /*! Adds member definition \a md to the list of all members of this file */
 void FileDef::insertMember(MemberDef *md)
 {
-  //printf("%s:FileDef::insertMember(%s)\n",name().data(),md->name().data());
+  //printf("%s:FileDef::insertMember(%s (=%p) list has %d elements)\n",
+  //    name().data(),md->name().data(),md,allMemberList.count());
+  if (allMemberList.findRef(md)!=-1) 
+  { 
+    return;
+  }
+
   allMemberList.append(md); 
   bool sortBriefDocs = Config_getBool("SORT_BRIEF_DOCS");
   bool sortMemberDocs = Config_getBool("SORT_MEMBER_DOCS");
-  switch(md->memberType())
+  switch (md->memberType())
   {
     case MemberDef::Variable:     
     case MemberDef::Property:     
@@ -740,6 +762,7 @@ void FileDef::insertNamespace(NamespaceDef *nd)
 
 void FileDef::addSourceRef(int line,Definition *d,MemberDef *md)
 {
+  //printf("FileDef::addSourceDef(%d,%p,%p)\n",line,d,md);
   if (d)
   {
     if (srcDefDict==0)    srcDefDict    = new QIntDict<Definition>(257);
@@ -1115,7 +1138,7 @@ static void addDirsAsGroups(Directory *root,GroupDef *parent,int level)
   GroupDef *gd=0;
   if (root->kind()==DirEntry::Dir)
   {
-    gd = new GroupDef("<generated>",
+    gd = new GroupDef("[generated]",
                       1,
                       root->path(), // name
                       root->name()  // title
@@ -1220,7 +1243,7 @@ void FileDef::acquireFileVersion()
   if (!vercmd.isEmpty()) 
   {
     msg("Version of %s : ",filepath.data());
-    FILE *f=popen(vercmd+" "+filepath,"r");
+    FILE *f=popen("\""+vercmd+"\" \""+filepath+"\"","r");
     if (!f)
     {
       err("Error: could not execute %s\n",vercmd.data());
@@ -1243,3 +1266,28 @@ void FileDef::acquireFileVersion()
 }
 
 
+QCString FileDef::getSourceFileBase() const
+{ 
+  if (Htags::useHtags)
+  {
+    return Htags::path2URL(filepath);
+  }
+  else
+  {
+    return convertNameToFile(diskname+"-source"); 
+  }
+}
+
+/*! Returns the name of the verbatim copy of this file (if any). */
+QCString FileDef::includeName() const 
+{ 
+  if (Htags::useHtags)
+  {
+    return Htags::path2URL(filepath);
+  }
+  else
+  {
+    return convertNameToFile(diskname+"-source"); 
+  }
+}
+
