@@ -369,6 +369,8 @@ void FTVHelp::initialize()
 void FTVHelp::finalize()
 {
   generateTreeView();
+  delete m_theInstance;
+  m_theInstance=0;
 }
 
 /*! Increase the level of the contents hierarchy. 
@@ -625,9 +627,12 @@ void FTVHelp::generateTreeView()
   else
   {
     QTextStream t(&f);
+#if QT_VERSION >= 200
+    t.setEncoding(QTextStream::Latin1);
+#endif
     t << "<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en\" lang=\"en\">\n";
     t << "  <head>\n";
-    t << "    <meta http-equiv=\"Content-Type\" content=\"text/xhtml;charset=\""
+    t << "    <meta http-equiv=\"Content-Type\" content=\"text/xhtml;charset="
       << theTranslator->idLanguageCharset() << "\" />\n";
     t << "    <meta http-equiv=\"Content-Style-Type\" content=\"text/css\" />\n";
     t << "    <meta http-equiv=\"Content-Language\" content=\"en\" />\n";
@@ -660,54 +665,29 @@ void FTVHelp::generateTreeView()
     t << "    <script type=\"text/javascript\">\n";
     t << "    <!-- // Hide script from old browsers\n";
     t << "    \n";
-    t << "    function findChildNode(node, name) \n";
-    t << "    {\n";
-    t << "      var temp;\n";
-    t << "      if (node == null) \n";
-    t << "      {\n";
-    t << "        return null;\n";
-    t << "      } \n";
-    t << "      node = node.firstChild;\n";
-    t << "      while (node != null) \n";
-    t << "      {\n";
-    t << "        if (node.nodeName == name) \n";
-    t << "        {\n";
-    t << "          return node;\n";
-    t << "        }\n";
-    t << "        temp = findChildNode(node, name);\n";
-    t << "        if (temp != null) \n";
-    t << "        {\n";
-    t << "          return temp;\n";
-    t << "        }\n";
-    t << "        node = node.nextSibling;\n";
-    t << "      }\n";
-    t << "      return null;\n";
-    t << "    }\n";
-    t << "\n";
+
+            /* User has clicked on a node (folder or +/-) in the tree */
     t << "    function toggleFolder(id, imageNode) \n";
     t << "    {\n";
     t << "      var folder = document.getElementById(id);\n";
-    t << "      var l = 0;\n";
-    t << "      var vl = \"" FTV_ICON_FILE(vertline) "\";\n";
-    t << "      if (imageNode != null && imageNode.nodeName != \"IMG\") \n";
+    t << "      var l = imageNode.src.length;\n";
+                /* If the user clicks on the book icon, we move left one image so 
+                 * the code (below) will also adjust the '+' icon. 
+                 */
+    t << "      if (imageNode.src.substring(l-20,l)==\"" FTV_ICON_FILE(folderclosed) "\" || \n";
+    t << "          imageNode.src.substring(l-18,l)==\"" FTV_ICON_FILE(folderopen)  "\")\n";
     t << "      {\n";
-    t << "        imageNode = findChildNode(imageNode, \"IMG\");\n";
-    t << "        if (imageNode!=null) l = imageNode.src.length;\n";
+    t << "        imageNode = imageNode.previousSibling;\n";
+    t << "        l = imageNode.src.length;\n";
     t << "      }\n";
     t << "      if (folder == null) \n";
     t << "      {\n";
     t << "      } \n";
+                /* Node controls a open section, we need to close it */
     t << "      else if (folder.style.display == \"block\") \n";
     t << "      {\n";
-    t << "        while (imageNode != null && \n";
-    t << "               imageNode.src.substring(l-vl.length,l) == vl)\n";
-    t << "        {\n";
-    t << "          imageNode = imageNode.nextSibling;\n";
-    t << "          l = imageNode.src.length;\n";
-    t << "        }\n";
     t << "        if (imageNode != null) \n";
     t << "        {\n";
-    t << "          l = imageNode.src.length;\n";
     t << "          imageNode.nextSibling.src = \"" FTV_ICON_FILE(folderclosed) "\";\n";
     t << "          if (imageNode.src.substring(l-13,l) == \"" FTV_ICON_FILE(mnode) "\")\n";
     t << "          {\n";
@@ -720,17 +700,10 @@ void FTVHelp::generateTreeView()
     t << "        }\n";
     t << "        folder.style.display = \"none\";\n";
     t << "      } \n";
-    t << "      else \n";
+    t << "      else \n"; /* section is closed, we need to open it */
     t << "      {\n";
-    t << "        while (imageNode != null && \n";
-    t << "               imageNode.src.substring(l-vl.length,l) == vl)\n";
-    t << "        {\n";
-    t << "          imageNode = imageNode.nextSibling;\n";
-    t << "          l = imageNode.src.length;\n";
-    t << "        }\n";
     t << "        if (imageNode != null) \n";
     t << "        {\n";
-    t << "          l = imageNode.src.length;\n";
     t << "          imageNode.nextSibling.src = \"" FTV_ICON_FILE(folderopen) "\";\n";
     t << "          if (imageNode.src.substring(l-13,l) == \"" FTV_ICON_FILE(pnode) "\")\n";
     t << "          {\n";
@@ -749,7 +722,7 @@ void FTVHelp::generateTreeView()
     t << "    </script>\n";
     t << "  </head>\n";
     t << "\n";
-    t << "  <body bgcolor=\"#ffffff\">\n";
+    t << "  <body>\n";
     t << "    <div class=\"directory\">\n";
     t << "      <h3>";
     QCString &projName = Config_getString("PROJECT_NAME");
