@@ -2,7 +2,7 @@
  *
  * $Id: latexgen.cpp,v 1.58 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -31,6 +31,7 @@
 #include "pagedef.h"
 #include "docparser.h"
 #include "latexdocvisitor.h"
+#include "dirdef.h"
 
 //static QCString filterTitle(const char *s)
 //{
@@ -51,6 +52,7 @@
 //  return result;  
 //}
 
+
 static QCString escapeLabelName(const char *s)
 {
   QCString result;
@@ -100,38 +102,13 @@ LatexGenerator::LatexGenerator() : OutputGenerator()
   //printf("LatexGenerator::LatexGenerator() insideTabbing=FALSE\n");
   insideTabbing=FALSE;
   firstDescItem=TRUE;
-  insidePre=FALSE;
+  m_indent=0;
 }
 
 LatexGenerator::~LatexGenerator()
 {
 }
 
-//LatexGenerator::LatexGenerator(const LatexGenerator &g)
-//  : OutputGenerator(g)
-//{
-//  col=g.col;
-//}
-
-//void LatexGenerator::append(const OutputGenerator *g)
-//{
-//  t << g->getContents();
-//  col+=((LatexGenerator *)g)->col;
-//  insideTabbing=insideTabbing || ((LatexGenerator *)g)->insideTabbing;
-//  firstDescItem = ((LatexGenerator *)g)->firstDescItem;
-//  insidePre = insidePre || ((LatexGenerator *)g)->insidePre;
-//  //printf("LatexGenerator::append(%s) insideTabbing=%s\n", g->getContents().data(),
-//  //    insideTabbing ? "TRUE" : "FALSE" );
-//}
-
-//OutputGenerator *LatexGenerator::copy()
-//{
-//  LatexGenerator *result = new LatexGenerator;
-//  result->insideTabbing=insideTabbing;
-//  result->insidePre=insidePre;
-//  return result;
-//}
-
 void LatexGenerator::init()
 {
   QCString dir=Config_getString("LATEX_OUTPUT");
@@ -156,7 +133,7 @@ void LatexGenerator::init()
   QTextStream t(&file);
   if (!Config_getBool("USE_PDFLATEX")) // use plain old latex
   {
-    t << "all: refman.dvi" << endl
+    t << "all: clean refman.dvi" << endl
       << endl
       << "ps: refman.ps" << endl
       << endl
@@ -205,7 +182,7 @@ void LatexGenerator::init()
   }
   else // use pdflatex for higher quality output
   {
-    t << "all: refman.pdf" << endl << endl;
+    t << "all: clean refman.pdf" << endl << endl;
     t << "refman.pdf: refman.tex" << endl;
     t << "\tpdflatex refman.tex" << endl;
     t << "\tmakeindex refman.idx" << endl;
@@ -222,6 +199,8 @@ void LatexGenerator::init()
   t << endl
     << "clean:" << endl
     << "\trm -f *.ps *.dvi *.aux *.toc *.idx *.ind *.ilg *.log *.out refman.pdf" << endl;
+
+  createSubDirs(d);
 }
 
 static void writeDefaultHeaderPart1(QTextStream &t)
@@ -250,9 +229,12 @@ static void writeDefaultHeaderPart1(QTextStream &t)
     "\\usepackage{alltt}\n"
     //"\\usepackage{ae,aecompl,aeguill}\n"
     ;
-  if (Config_getBool("PDF_HYPERLINKS")) 
+  if (Config_getBool("USE_PDFLATEX"))
   {
     t << "\\usepackage{times}" << endl;
+  }
+  if (Config_getBool("PDF_HYPERLINKS")) 
+  {
     t << "\\ifx\\pdfoutput\\undefined" << endl
       << "\\usepackage[ps2pdf," << endl
       << "            pagebackref=true," << endl
@@ -429,18 +411,19 @@ void LatexGenerator::writeStyleSheetFile(QFile &f)
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2004";
+  //t << "Dimitri van Heesch \\copyright~1997-2005";
   writeDefaultStyleSheetPart2(t);
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2004";
+  //t << "Dimitri van Heesch \\copyright~1997-2005";
   writeDefaultStyleSheetPart3(t);
 }
 
 void LatexGenerator::startFile(const char *name,const char *,const char *)
 {
   QCString fileName=name;
+  relPath = relativePathToRoot(fileName);
   if (fileName.right(4)!=".tex" && fileName.right(4)!=".sty") fileName+=".tex";
   startPlainFile(fileName);
 }
@@ -497,6 +480,10 @@ void LatexGenerator::startIndexSection(IndexSections is)
       if (compactLatex) t << "\\section"; else t << "\\chapter";
       t << "{"; //Module Index}\n"
       break;
+    case isDirIndex:
+      if (compactLatex) t << "\\section"; else t << "\\chapter";
+      t << "{"; //Directory Index}\n"
+      break;
     case isNamespaceIndex:
       if (compactLatex) t << "\\section"; else t << "\\chapter";
       t << "{"; //Namespace Index}\"
@@ -533,6 +520,22 @@ void LatexGenerator::startIndexSection(IndexSections is)
         }
       }
       break;
+    case isDirDocumentation:
+      {
+        SDict<DirDef>::Iterator dli(Doxygen::directories);
+        DirDef *dd;
+        bool found=FALSE;
+        for (dli.toFirst();(dd=dli.current()) && !found;++dli)
+        {
+          if (dd->isLinkableInProject())
+          {
+            if (compactLatex) t << "\\section"; else t << "\\chapter";
+            t << "{"; //Module Documentation}\n";
+            found=TRUE;
+          }
+        }
+      }
+      break;
     case isNamespaceDocumentation:
       {
         NamespaceSDict::Iterator nli(Doxygen::namespaceSDict);
@@ -633,6 +636,9 @@ void LatexGenerator::endIndexSection(IndexSections is)
     case isModuleIndex:
       t << "}\n\\input{modules}\n";
       break;
+    case isDirIndex:
+      t << "}\n\\input{dirs}\n";
+      break;
     case isNamespaceIndex:
       t << "}\n\\input{namespaces}\n";
       break;
@@ -671,6 +677,29 @@ void LatexGenerator::endIndexSection(IndexSections is)
         }
       }
       break;
+    case isDirDocumentation:
+      {
+        SDict<DirDef>::Iterator dli(Doxygen::directories);
+        DirDef *dd;
+        bool found=FALSE;
+        for (dli.toFirst();(dd=dli.current()) && !found;++dli)
+        {
+          if (dd->isLinkableInProject())
+          {
+            t << "}\n\\input{" << dd->getOutputFileBase() << "}\n";
+            found=TRUE;
+          }
+        }
+        for (;(dd=dli.current());++dli)
+        {
+          if (dd->isLinkableInProject())
+          {
+            if (compactLatex) t << "\\input"; else t << "\\include";
+            t << "{" << dd->getOutputFileBase() << "}\n";
+          }
+        }
+      }
+      break;
     case isNamespaceDocumentation:
       {
         NamespaceSDict::Iterator nli(Doxygen::namespaceSDict);
@@ -802,14 +831,14 @@ void LatexGenerator::writeStyleInfo(int part)
       break;
     case 2:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2004";
+        //t << " Dimitri van Heesch \\copyright~1997-2005";
         t << "}]{}\n";
         writeDefaultStyleSheetPart2(t);
       }
       break;
     case 4:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2004";
+        //t << " Dimitri van Heesch \\copyright~1997-2005";
         writeDefaultStyleSheetPart3(t);
         endPlainFile();
       }
@@ -926,7 +955,7 @@ void LatexGenerator::startTextLink(const char *f,const char *anchor)
   if (Config_getBool("PDF_HYPERLINKS"))
   {
     t << "\\hyperlink{";
-    if (f) t << f;
+    if (f) t << stripPath(f);
     if (anchor) t << "_" << anchor; 
     t << "}{";
   }
@@ -947,7 +976,7 @@ void LatexGenerator::writeObjectLink(const char *ref, const char *f,
   if (!ref && Config_getBool("PDF_HYPERLINKS"))
   {
     t << "\\hyperlink{";
-    if (f) t << f;
+    if (f) t << stripPath(f);
     if (f && anchor) t << "_"; 
     if (anchor) t << anchor; 
     t << "}{";
@@ -986,7 +1015,7 @@ void LatexGenerator::startTitleHead(const char *fileName)
 {
   if (Config_getBool("PDF_HYPERLINKS") && fileName)
   {
-    t << "\\hypertarget{" << fileName << "}{" << endl;
+    t << "\\hypertarget{" << stripPath(fileName) << "}{" << endl;
   }
   if (Config_getBool("COMPACT_LATEX")) 
   {
@@ -1100,19 +1129,20 @@ void LatexGenerator::startMemberDoc(const char *clname,
   t << "{\\setlength{\\rightskip}{0pt plus 5cm}";
 }
 
-void LatexGenerator::endMemberDoc() 
+void LatexGenerator::endMemberDoc(bool) 
 { 
   t << "}";
   if (Config_getBool("COMPACT_LATEX")) t << "\\hfill";
 }
 
 void LatexGenerator::startDoxyAnchor(const char *fName,const char *,
-                                     const char *anchor, const char *)
+                                     const char *anchor, const char *,
+                                     const char *)
 {
   if (Config_getBool("PDF_HYPERLINKS"))
   {
     t << "\\hypertarget{";
-    if (fName) t << fName;
+    if (fName) t << stripPath(fName);
     if (anchor) t << "_" << anchor;
     t << "}{" << endl;
   }
@@ -1136,7 +1166,7 @@ void LatexGenerator::writeAnchor(const char *fName,const char *name)
   t << "\\label{" << name << "}" << endl; 
   if (fName && Config_getBool("PDF_HYPERLINKS"))
   {
-    t << "\\hypertarget{" << fName << "_" << name << "}{}" << endl;
+    t << "\\hypertarget{" << stripPath(fName) << "_" << name << "}{}" << endl;
   }
 }
 
@@ -1168,7 +1198,7 @@ void LatexGenerator::startSection(const char *lab,const char *,SectionInfo::Sect
 {
   if (Config_getBool("PDF_HYPERLINKS"))
   {
-    t << "\\hypertarget{" << lab << "}{}";
+    t << "\\hypertarget{" << stripPath(lab) << "}{}";
   }
   t << "\\";
   if (Config_getBool("COMPACT_LATEX"))
@@ -1208,7 +1238,7 @@ void LatexGenerator::endSection(const char *lab,SectionInfo::SectionType)
 //void LatexGenerator::docifyStatic(QTextStream &t,const char *str)
 void LatexGenerator::docify(const char *str)
 {
-  filterLatexString(t,str,insideTabbing,insidePre);
+  filterLatexString(t,str,insideTabbing,FALSE);
 }
 
 void LatexGenerator::codify(const char *str)
@@ -1317,12 +1347,42 @@ void LatexGenerator::endMemberItem()
   t << endl; 
 }
 
+void LatexGenerator::startMemberDescription() 
+{
+  if (!insideTabbing)
+  { 
+    t << "\\begin{CompactList}\\small\\item\\em "; 
+  }
+  else
+  {
+    for (int i=0;i<m_indent+1;i++) t << "\\>";
+    t << "{\\em ";
+  }
+}
+
+void LatexGenerator::endMemberDescription() 
+{ 
+  if (!insideTabbing)
+  {
+    t << "\\item\\end{CompactList}"; 
+  }
+  else
+  {
+    t << "}\\\\";
+    m_indent=0;
+  }
+}
+
+
 void LatexGenerator::writeNonBreakableSpace(int) 
 {
   if (insideTabbing)
+  {
     t << "\\>";
+    m_indent++;
+  }
   else
-    t << "\\ "; 
+    t << "~"; 
 }
 
 void LatexGenerator::startMemberList()  
@@ -1380,7 +1440,7 @@ void LatexGenerator::startDotGraph()
 
 void LatexGenerator::endDotGraph(DotClassGraph &g) 
 {
-  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"));
+  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
 }
 
 void LatexGenerator::startInclDepGraph() 
@@ -1389,7 +1449,16 @@ void LatexGenerator::startInclDepGraph()
 
 void LatexGenerator::endInclDepGraph(DotInclDepGraph &g) 
 {
-  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"));
+  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
+}
+
+void LatexGenerator::startGroupCollaboration() 
+{
+}
+
+void LatexGenerator::endGroupCollaboration(DotGroupCollaboration &g) 
+{
+  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
 }
 
 void LatexGenerator::startCallGraph() 
@@ -1398,7 +1467,16 @@ void LatexGenerator::startCallGraph()
 
 void LatexGenerator::endCallGraph(DotCallGraph &g) 
 {
-  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"));
+  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
+}
+
+void LatexGenerator::startDirDepGraph() 
+{
+}
+
+void LatexGenerator::endDirDepGraph(DotDirDeps &g) 
+{
+  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
 }
 
 void LatexGenerator::startDescription() 
@@ -1464,9 +1542,9 @@ void LatexGenerator::endParamList()
 }
 
 
-void LatexGenerator::printDoc(DocNode *n)
+void LatexGenerator::printDoc(DocNode *n,const char *langExt)
 {
-  LatexDocVisitor *visitor = new LatexDocVisitor(t,*this);
+  LatexDocVisitor *visitor = new LatexDocVisitor(t,*this,langExt,insideTabbing);
   n->accept(visitor);
   delete visitor; 
 }
