@@ -17,6 +17,7 @@
 
 #include <stdio.h>
 #include <qregexp.h>
+#include <md5.h>
 #include "memberdef.h"
 #include "membername.h"
 #include "doxygen.h"
@@ -1939,12 +1940,13 @@ void MemberDef::warnIfUndocumented()
     t="group", d=gd;
   else
     t="file", d=fd;
+  static bool extractAll = Config_getBool("EXTRACT_ALL");
 
   //printf("warnIfUndoc: d->isLinkable()=%d isLinkable()=%d "
   //       "isDocumentedFriendClass()=%d name()=%s prot=%d\n",
   //       d->isLinkable(),isLinkable(),isDocumentedFriendClass(),
   //       name().data(),prot);
-  if (!isLinkable() && 
+  if ((!hasUserDocumentation() && !extractAll) &&
       !isFriendClass() && 
       name().find('@')==-1 && d->name().find('@')==-1 &&
       (prot!=Private || Config_getBool("EXTRACT_PRIVATE"))
@@ -2006,9 +2008,45 @@ QCString MemberDef::getScopeString() const
   return result;
 }
 
+#if 0
+static QCString escapeAnchor(const QCString &anchor)
+{
+  QCString result;
+  int l = anchor.length(),i;
+  for (i=0;i<l;i++)
+  {
+    char c = anchor.at(i);
+    if ((c>='a' && c<='z') || (c>='A' && c<='Z'))
+    {
+      result+=c;
+    }
+    else
+    {
+      static char hexStr[]="0123456789ABCDEF";
+      char escChar[]={ '_', 0, 0, 0 };
+      escChar[1]=hexStr[c>>4];
+      escChar[2]=hexStr[c&0xf];
+      result+=escChar;
+    }
+  }
+  return result;
+}
+#endif
+
 void MemberDef::setAnchor(const char *a)
 {
-  anc=a;
+  //anc=a;
+  a=a;
+  QCString memAnchor = name();
+  if (!args.isEmpty()) memAnchor+=args;
+  //anc = escapeAnchor(memAnchor);
+  
+  // convert to md5 hash
+  uchar md5_sig[16];
+  QCString sigStr(33);
+  MD5Buffer((const unsigned char *)memAnchor.data(),memAnchor.length(),md5_sig);
+  MD5SigToString(md5_sig,sigStr.data(),33);
+  anc = sigStr;
 }
 
 void MemberDef::setGroupDef(GroupDef *gd,Grouping::GroupPri_t pri,
