@@ -18,12 +18,15 @@
 #include "definition.h"
 #include "sortdict.h"
 
+class PageSDict;
+class OutputList;
+
 class PageDef : public Definition
 {
   public:
     PageDef(const char *f,int l,const char *n,const char *d,const char *t);
    ~PageDef();
-    DefType definitionType() { return TypePage; }
+    DefType definitionType() const { return TypePage; }
     bool isLinkableInProject() const 
     { 
       return hasDocumentation() && !isReference();
@@ -32,18 +35,26 @@ class PageDef : public Definition
     {
       return isLinkableInProject() || isReference();
     } 
+    void addSubPage(PageDef *def);
+    void writeDocumentation(OutputList &ol);
 
     // functions to get a uniform interface with Definitions
     QCString getOutputFileBase() const;
     void findSectionsInDocumentation();
     QCString title() const { return m_title; }
-    GroupDef *getGroupDef() const;
+    GroupDef *  getGroupDef() const;
+    PageSDict * getSubPages() const { return subPageDict; }
     void setFileName(const char *name) { m_fileName = name; }
+    void addInnerCompound(Definition *d);
+    bool visibleInIndex() const;
+    bool documentedPage() const;
+    bool hasSubPages() const;
 
   private:
     QCString m_fileName;
     QCString m_title;
     GroupDef *m_inGroup;
+    PageSDict *subPageDict;                 // list of pages in the group
 };
 
 class PageSDict : public SDict<PageDef>
