@@ -532,6 +532,12 @@ void PerlModDocVisitor::visit(DocSymbol *sy)
   case DocSymbol::Hash:    c = '#'; break;
   case DocSymbol::Percent: c = '%'; break;
   case DocSymbol::Quot:    c = '"'; break;
+  case DocSymbol::Lsquo:   s = "\\\'"; break;
+  case DocSymbol::Rsquo:   s = "\\\'"; break;
+  case DocSymbol::Ldquo:   c = '"'; break;
+  case DocSymbol::Rdquo:   c = '"'; break;
+  case DocSymbol::Ndash:   c = '-'; break;
+  case DocSymbol::Mdash:   s = "--"; break;
   case DocSymbol::Nbsp:    c = ''; break;
   case DocSymbol::Uml:     accent = "umlaut"; break;
   case DocSymbol::Acute:   accent = "acute"; break;
@@ -1165,10 +1171,21 @@ void PerlModDocVisitor::visitPre(DocParamList *pl)
   leaveText();
   m_output.openHash()
     .openList("parameters");
-  QStrListIterator li(pl->parameters());
-  const char *s;
-  for (li.toFirst();(s=li.current());++li)
+  //QStrListIterator li(pl->parameters());
+  //const char *s;
+  QListIterator<DocNode> li(pl->parameters());
+  DocNode *param;
+  for (li.toFirst();(param=li.current());++li)
   {
+    QCString s;
+    if (param->kind()==DocNode::Kind_Word)
+    {
+      s = ((DocWord*)param)->word(); 
+    }
+    else if (param->kind()==DocNode::Kind_LinkedWord)
+    {
+      s = ((DocLinkedWord*)param)->word(); 
+    }
     m_output.openHash()
       .addFieldQuotedString("name", s)
       .closeHash();
