@@ -14,6 +14,8 @@
  * input used in their production; they are not affected by this license.
  *
  * The translation into German was provided by
+ *   Jens Seidel (jensseidel@users.sf.net)
+ * based on work from
  *   Jens Breitenstein (Jens.Breitenstein@tlc.de)
  */
 
@@ -96,6 +98,16 @@
 //    - added a dash after (file, ...) names and in front of description
 //    - changed "Eigenschaften" to "Propertys" (yeah, not ..."ies")
 //    
+//   2005/03/20 Jens Seidel (jensseidel@users.sourceforge.net)
+//    - Updated for "new since 1.4.1" version
+//    
+//   2005/04/09 Jens Seidel (jensseidel@users.sourceforge.net)
+//    - Changed Todo list translation as suggested in
+//      http://bugzilla.gnome.org/show_bug.cgi?id=172818
+//    
+//   2005/05/09 Jens Seidel (jensseidel@users.sourceforge.net)
+//    - Updated for "new since 1.4.3" version (removed unused methods)
+//
 //   Todo:
 //    - see FIXME
 
@@ -237,10 +249,6 @@ class TranslatorGerman : public Translator
     virtual QCString trFileList()
     { return "Auflistung der Dateien"; }
 
-    /*! This is put above each page as a link to the list of all verbatim headers */
-    virtual QCString trHeaderFiles()
-    { return "Header-Dateien"; }
-
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     { 
@@ -364,10 +372,6 @@ class TranslatorGerman : public Translator
       return result;
     }
 
-    /*! This is an introduction to the page with the list of all header files. */
-    virtual QCString trHeaderFilesDescription()
-    { return "Hier folgen die Headerdateien, welche die API definieren:"; }
-
     /*! This is an introduction to the page with the list of all examples */
     virtual QCString trExamplesDescription()
     { return "Hier folgt eine Liste mit allen Beispielen:"; }
@@ -380,12 +384,6 @@ class TranslatorGerman : public Translator
     virtual QCString trModulesDescription()
     { return "Hier folgt die Aufzhlung aller Module:"; }
 
-    /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given. 
-     */
-    virtual QCString trNoDescriptionAvailable()
-    { return "Keine Beschreibung verfgbar"; }
-
     // index titles (the project name is prepended for these) 
 
     /*! This is used in HTML as the title of index.html. */
@@ -530,12 +528,6 @@ class TranslatorGerman : public Translator
     virtual QCString trEnumerationTypeDocumentation()
     { return "Dokumentation der Aufzhlungstypen"; }
 
-    /*! This is used in the documentation of a file/namespace before the list 
-     *  of documentation blocks for enumeration values
-     */
-    virtual QCString trEnumerationValueDocumentation()
-    { return "Dokumentation des Wertebereiches der Aufzhlungstypen"; }
-
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for functions
      */
@@ -591,19 +583,10 @@ class TranslatorGerman : public Translator
     virtual QCString trForInternalUseOnly()
     { return "Nur fr den internen Gebrauch."; }
 
-    /*! this text is generated when the \\reimp command is used. */
-    virtual QCString trReimplementedForInternalReasons()
-    { return "Aus internen Grnden neu implementiert. "
-             "Das API wird davon nicht berhrt."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Warnung"; }
 
-    /*! this text is generated when the \\bug command is used. */
-    virtual QCString trBugsAndLimitations()
-    { return "Fehler und Einschrnkungen"; }
-
     /*! this text is generated when the \\version command is used. */
     virtual QCString trVersion()
     { return "Version"; }
@@ -888,11 +871,6 @@ class TranslatorGerman : public Translator
 // new since 0.49-991003
 //////////////////////////////////////////////////////////////////////////
 
-    virtual QCString trSources()
-    {
-      return "Quellen";
-    }
-
     virtual QCString trDefinedAtLineInSourceFile()
     {
       return "Definiert in Zeile @0 der Datei @1.";
@@ -1071,7 +1049,7 @@ class TranslatorGerman : public Translator
     /*! Used as the header of the todo list */
     virtual QCString trTodoList()
     {
-      return "Liste der zu erledigenden Dinge";
+      return "Ausstehende Aufgaben";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1236,12 +1214,6 @@ class TranslatorGerman : public Translator
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return "Schnittstellen";
-    }
-
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -1275,12 +1247,6 @@ class TranslatorGerman : public Translator
       return "Pakete";
     }
 
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return "Paketdokumentation";
-    }
-
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1397,17 +1363,6 @@ class TranslatorGerman : public Translator
       return result;
     }
    
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
-     *  of the category.
-     */
-    virtual QCString trField(bool, bool singular)
-    {
-      QCString result("Feld");
-      if (!singular)  result+="er";
-      return result;
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names 
      *  of the category.
@@ -1645,7 +1600,7 @@ class TranslatorGerman : public Translator
     { return "Verzeichnisdokumentation"; }
 
     /*! This is used as the title of the directory index and also in the
-     *  Quick links of a HTML page, to link to the directory hierarchy.
+     *  Quick links of an HTML page, to link to the directory hierarchy.
      */
     virtual QCString trDirectories()
     { return "Verzeichnisse"; }
@@ -1674,6 +1629,20 @@ class TranslatorGerman : public Translator
       return result; 
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return "Dies ist eine berladene Methode, die der Bequemlichkeit "
+              "wegen bereitgestellt wird. Sie unterscheidet sich von der "
+              "obigen Funktion nur in den Argumenten die sie untersttzt.";
+    }
+
 };
 
 #endif
