@@ -57,6 +57,7 @@ class Definition;
 class TextGeneratorIntf
 {
   public:
+    virtual ~TextGeneratorIntf() {}
     virtual void writeString(const char *,bool) const = 0;
     virtual void writeBreak() const = 0;
     virtual void writeLink(const char *extRef,const char *file,
@@ -67,6 +68,7 @@ class TextGeneratorIntf
 class TextGeneratorOLImpl : public TextGeneratorIntf
 {
   public:
+    virtual ~TextGeneratorOLImpl() {}
     TextGeneratorOLImpl(OutputDocInterface &od);
     void writeString(const char *s,bool keepSpaces) const;
     void writeBreak() const;
@@ -129,10 +131,12 @@ void generateFileRef(OutputDocInterface &od,const char *,
                              const char *linkTxt=0);
 void writePageRef(OutputDocInterface &od,const char *cn,const char *mn);
 
+#if 0
 bool matchArguments(ArgumentList *,ArgumentList *,
                            const char *cl=0,const char *ns=0,bool checkCV=TRUE,
                            NamespaceSDict *usingNamespaces=0,
                            SDict<Definition> *usingClasses=0);
+#endif
 bool matchArguments2(Definition *srcScope,FileDef *srcFileScope,ArgumentList *srcAl,
                      Definition *dstScope,FileDef *dstFileScope,ArgumentList *dstAl,
                      bool checkCV
@@ -147,7 +151,8 @@ ClassDef *getResolvedClass(Definition *scope,
                            const char *key,
                            MemberDef **pTypeDef=0,
                            QCString *pTemplSpec=0,
-                           bool mayBeUnlinkable=FALSE);
+                           bool mayBeUnlinkable=FALSE,
+                           bool mayBeHidden=FALSE);
 NamespaceDef *getResolvedNamespace(const char *key);
 FileDef *findFileDef(const FileNameDict *fnDict,const char *n,
                 bool &ambig);
@@ -155,7 +160,7 @@ QCString showFileDefMatches(const FileNameDict *fnDict,const char *n);
 int guessSection(const char *name);
 bool isId(char c);
 QCString removeRedundantWhiteSpace(const QCString &s);
-QCString argListToString(ArgumentList *al);
+QCString argListToString(ArgumentList *al,bool useCanonicalType=FALSE);
 QCString tempArgListToString(ArgumentList *al);
 QCString generateMarker(int id);
 void writeExample(OutputList &ol,ExampleSDict *el);
@@ -180,11 +185,11 @@ QCString stripScope(const char *name);
 int iSystem(const char *command,const char *args,bool isBatchFile=FALSE);
 QCString convertToHtml(const char *s);
 QCString convertToXML(const char *s);
-const char * getOverloadDocs();
+QCString getOverloadDocs();
 void addMembersToMemberGroup(MemberList *ml,
                              MemberGroupSDict *memberGroupSDict,
                              Definition *context);
-bool extractClassNameFromType(const QCString &type,int &pos,
+int extractClassNameFromType(const QCString &type,int &pos,
                               QCString &name,QCString &templSpec);
 QCString substituteTemplateArgumentsInString(
        const QCString &name,
@@ -222,12 +227,18 @@ void replaceNamespaceAliases(QCString &scope,int i);
 int isAccessibleFrom(Definition *scope,FileDef *fileScope,Definition *item);
 int isAccessibleFromWithExpScope(Definition *scope,FileDef *fileScope,Definition *item,
                      const QCString &explicitScopePart);
-int computeQualifiedIndex(const QString &name);
+int computeQualifiedIndex(const QCString &name);
 void addDirPrefix(QCString &fileName);
 QCString relativePathToRoot(const char *name);
 #define REL_PATH_TO_ROOT "../../"
 void createSubDirs(QDir &d);
 QCString stripPath(const char *s);
+bool containsWord(const QCString &s,const QCString &word);
+bool findAndRemoveWord(QCString &s,const QCString &word);
+QCString stripLeadingAndTrailingEmptyLines(const QCString &s);
+void stringToSearchIndex(const QCString &docUrlBase,const QCString &title,
+                         const QCString &str, bool priority=FALSE,
+                         const QCString &anchor="");
 
 #endif
 
