@@ -22,13 +22,13 @@
 #include "doxygen.h"
 #include "outputgen.h"
 #include "xmlgen.h"
-#include "code.h"
 #include "dot.h"
 #include "message.h"
 #include "util.h"
 #include <qfileinfo.h> 
+#include "parserintf.h"
 
-XmlDocVisitor::XmlDocVisitor(QTextStream &t,BaseCodeDocInterface &ci) 
+XmlDocVisitor::XmlDocVisitor(QTextStream &t,CodeOutputInterface &ci) 
   : DocVisitor(DocVisitor_XML), m_t(t), m_ci(ci), m_insidePre(FALSE), m_hide(FALSE) 
 {
 }
@@ -82,6 +82,12 @@ void XmlDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Reg:     m_t << "<registered/>"; break;
     case DocSymbol::Apos:    m_t << "'"; break;
     case DocSymbol::Quot:    m_t << "\""; break;
+    case DocSymbol::Lsquo:   m_t << "<lsquo/>"; break;
+    case DocSymbol::Rsquo:   m_t << "<rsquo/>"; break;
+    case DocSymbol::Ldquo:   m_t << "<ldquo/>"; break;
+    case DocSymbol::Rdquo:   m_t << "<rdquo/>"; break;
+    case DocSymbol::Ndash:   m_t << "<ndash/>"; break;
+    case DocSymbol::Mdash:   m_t << "<mdash/>"; break;
     case DocSymbol::Uml:     m_t << "<umlaut char=\"" << s->letter() << "\"/>"; break;
     case DocSymbol::Acute:   m_t << "<acute char=\"" << s->letter() << "\"/>"; break;
     case DocSymbol::Grave:   m_t << "<grave char=\"" << s->letter() << "\"/>"; break;
@@ -169,7 +175,9 @@ void XmlDocVisitor::visit(DocVerbatim *s)
   {
     case DocVerbatim::Code: // fall though
       m_t << "<programlisting>"; 
-      parseCode(m_ci,s->context(),s->text().latin1(),s->isExample(),s->exampleFile());
+      Doxygen::parserManager->getParser(m_langExt)
+                            ->parseCode(m_ci,s->context(),s->text().latin1(),
+                                        s->isExample(),s->exampleFile());
       m_t << "</programlisting>"; 
       break;
     case DocVerbatim::Verbatim: 
@@ -219,13 +227,21 @@ void XmlDocVisitor::visit(DocInclude *inc)
          m_t << "<programlisting>";
          QFileInfo cfi( inc->file() );
          FileDef fd( cfi.dirPath(), cfi.fileName() );
-         parseCode(m_ci,inc->context(),inc->text().latin1(),inc->isExample(),inc->exampleFile(), &fd);
+         Doxygen::parserManager->getParser(inc->extension())
+                               ->parseCode(m_ci,inc->context(),
+                                           inc->text().latin1(),
+                                           inc->isExample(),
+                                           inc->exampleFile(), &fd);
          m_t << "</programlisting>"; 
       }
       break;    
     case DocInclude::Include: 
       m_t << "<programlisting>";
-      parseCode(m_ci,inc->context(),inc->text().latin1(),inc->isExample(),inc->exampleFile());
+      Doxygen::parserManager->getParser(inc->extension())
+                            ->parseCode(m_ci,inc->context(),
+                                        inc->text().latin1(),
+                                        inc->isExample(),
+                                        inc->exampleFile());
       m_t << "</programlisting>"; 
       break;
     case DocInclude::DontInclude: 
@@ -259,7 +275,13 @@ void XmlDocVisitor::visit(DocIncOperator *op)
   if (op->type()!=DocIncOperator::Skip) 
   {
     popEnabled();
-    if (!m_hide) parseCode(m_ci,op->context(),op->text().latin1(),op->isExample(),op->exampleFile());
+    if (!m_hide) 
+    {
+      Doxygen::parserManager->getParser(m_langExt)
+                            ->parseCode(m_ci,op->context(),
+                                        op->text().latin1(),op->isExample(),
+                                        op->exampleFile());
+    }
     pushEnabled();
     m_hide=TRUE;
   }
@@ -641,6 +663,21 @@ void XmlDocVisitor::visitPre(DocImage *img)
     m_t << "\"";
   }
   m_t << ">";
+
+  // copy the image to the output dir
+  QFile inImage(img->name());
+  QFile outImage(Config_getString("XML_OUTPUT")+"/"+baseName.ascii());
+  if (inImage.open(IO_ReadOnly))
+  {
+    if (outImage.open(IO_WriteOnly))
+    {
+      char *buffer = new char[inImage.size()];
+      inImage.readBlock(buffer,inImage.size());
+      outImage.writeBlock(buffer,inImage.size());
+      outImage.flush();
+      delete buffer;
+    }
+  }
 }
 
 void XmlDocVisitor::visitPost(DocImage *) 
@@ -752,9 +789,11 @@ void XmlDocVisitor::visitPre(DocParamList *pl)
   if (m_hide) return;
   m_t << "<parameteritem>" << endl;
   m_t << "<parameternamelist>" << endl;
-  QStrListIterator li(pl->parameters());
-  const char *s;
-  for (li.toFirst();(s=li.current());++li)
+  //QStrListIterator li(pl->parameters());
+  //const char *s;
+  QListIterator<DocNode> li(pl->parameters());
+  DocNode *param;
+  for (li.toFirst();(param=li.current());++li)
   {
     m_t << "<parametername";
     if (pl->direction()!=DocParamSect::Unspecified)
@@ -775,7 +814,14 @@ void XmlDocVisitor::visitPre(DocParamList *pl)
       m_t << "\"";
     }
     m_t << ">";
-    filter(s);
+    if (param->kind()==DocNode::Kind_Word)
+    {
+      visit((DocWord*)param); 
+    }
+    else if (param->kind()==DocNode::Kind_LinkedWord)
+    {
+      visit((DocLinkedWord*)param); 
+    }
     m_t << "</parametername>" << endl;
   }
   m_t << "</parameternamelist>" << endl;
