@@ -28,13 +28,13 @@
 #include "defargs.h"
 #include "outputgen.h"
 #include "dot.h"
-#include "code.h"
 #include "pagedef.h"
 #include "filename.h"
 #include "version.h"
 #include "xmldocvisitor.h"
 #include "docparser.h"
 #include "language.h"
+#include "parserintf.h"
 
 #include <qdir.h>
 #include <qfile.h>
@@ -222,7 +222,7 @@ template<class T> class ValStack
 };
 
 
-class XMLCodeGenerator : public BaseCodeDocInterface
+class XMLCodeGenerator : public CodeOutputInterface
 {
   public:
 
@@ -443,14 +443,15 @@ static void writeXMLDocBlock(QTextStream &t,
 
 void writeXMLCodeBlock(QTextStream &t,FileDef *fd)
 {
-  initParseCodeContext();
+  ParserInterface *pIntf=Doxygen::parserManager->getParser(fd->getDefFileExtension());
+  pIntf->resetCodeParserState();
   XMLCodeGenerator *xmlGen = new XMLCodeGenerator(t);
-  parseCode(*xmlGen,
-            0,
-            fileToString(fd->absFilePath(),Config_getBool("FILTER_SOURCE_FILES")),
-            FALSE,
-            0,
-            fd);
+  pIntf->parseCode(*xmlGen,
+                0,
+                fileToString(fd->absFilePath(),Config_getBool("FILTER_SOURCE_FILES")),
+                FALSE,
+                0,
+                fd);
   xmlGen->finish();
   delete xmlGen;
 }
@@ -478,6 +479,18 @@ static void writeMemberReference(QTextStream &t,Definition *def,MemberDef *rmd,c
   
 }
 
+static void stripQualifiers(QCString &typeStr)
+{
+  bool done=FALSE;
+  while (!done)
+  {
+    if (typeStr.stripPrefix("static "));
+    else if (typeStr.stripPrefix("virtual "));
+    else if (typeStr.stripPrefix("volatile "));
+    else done=TRUE;
+  }
+}
+
 static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,Definition *def)
 {
 
@@ -493,6 +506,7 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
   // - body code 
   // + template arguments 
   //     (templateArguments(), definitionTemplateParameterLists())
+  // - call graph
   
   // enum values are written as part of the enum
   if (md->memberType()==MemberDef::EnumValue) return;
@@ -550,9 +564,10 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
     case Private:   t << "private";    break;
     case Package:   t << "package";    break;
   }
-  t << "\" static=\"";
-  if (md->isStatic()) t << "yes"; else t << "no";
+  t << "\"";
 
+  t << " static=\"";
+  if (md->isStatic()) t << "yes"; else t << "no";
   t << "\"";
 
   if (isFunc)
@@ -560,40 +575,43 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
     ArgumentList *al = md->argumentList();
     t << " const=\"";
     if (al && al->constSpecifier)    t << "yes"; else t << "no"; 
+    t << "\"";
 
-    t << "\" explicit=\"";
+    t << " explicit=\"";
     if (md->isExplicit()) t << "yes"; else t << "no";
+    t << "\"";
 
-    t << "\" inline=\"";
+    t << " inline=\"";
     if (md->isInline()) t << "yes"; else t << "no";
+    t << "\"";
 
-	t << "\" virt=\"";
-	switch (md->virtualness())
-	{
-	case Normal:  t << "non-virtual";  break;
-	case Virtual: t << "virtual";      break;
-	case Pure:    t << "pure-virtual"; break;
-	default: ASSERT(0);
-	}
-
+    t << " virt=\"";
+    switch (md->virtualness())
+    {
+      case Normal:  t << "non-virtual";  break;
+      case Virtual: t << "virtual";      break;
+      case Pure:    t << "pure-virtual"; break;
+      default: ASSERT(0);
+    }
     t << "\"";
   }
 
   if (md->memberType() == MemberDef::Variable)
   {
-    ArgumentList *al = md->argumentList();
-    t << " volatile=\"";
-    if (al && al->volatileSpecifier) t << "yes"; else t << "no"; 
+    //ArgumentList *al = md->argumentList();
+    //t << " volatile=\"";
+    //if (al && al->volatileSpecifier) t << "yes"; else t << "no"; 
 
-    t << "\" mutable=\"";
+    t << " mutable=\"";
     if (md->isMutable()) t << "yes"; else t << "no";
-
     t << "\"";
   }
   else if (md->memberType() == MemberDef::Property)
   {
     t << " readable=\"";
     if (md->isReadable()) t << "yes"; else t << "no";
+    t << "\"";
+
     t << "\" writable=\"";
     if (md->isWritable()) t << "yes"; else t << "no";
     t << "\"";
@@ -611,6 +629,7 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
       writeMemberTemplateLists(md,t);
     }
     QCString typeStr = md->typeString(); //replaceAnonymousScopes(md->typeString());
+    stripQualifiers(typeStr);
     t << "        <type>";
     linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md->name(),typeStr);
     t << "</type>" << endl;
@@ -646,7 +665,7 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
         << convertToXML(rmd->name()) << "</reimplementedby>" << endl;
     }
   }
-  
+
   if (isFunc) //function
   {
     ArgumentList *declAl = md->declArgumentList();
@@ -709,13 +728,21 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
     }
   }
   else if (md->memberType()==MemberDef::Define && 
-           md->argsString()!=0) // define
+          md->argsString()) // define
   {
-    ArgumentListIterator ali(*md->argumentList());
-    Argument *a;
-    for (ali.toFirst();(a=ali.current());++ali)
+    if (md->argumentList()->count()==0) // special case for "foo()" to
+                                        // disguish it from "foo".
     {
-      t << "        <param><defname>" << a->type << "</defname></param>" << endl;
+      t << "        <param></param>" << endl;
+    }
+    else
+    {
+      ArgumentListIterator ali(*md->argumentList());
+      Argument *a;
+      for (ali.toFirst();(a=ali.current());++ali)
+      {
+        t << "        <param><defname>" << a->type << "</defname></param>" << endl;
+      }
     }
   }
   // avoid that extremely large tables are written to the output. 
@@ -791,6 +818,11 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
       << md->getDefLine() << "\"";
     if (md->getStartBodyLine()!=-1)
     {
+      FileDef *bodyDef = md->getBodyDef();
+      if (bodyDef)
+      {
+        t << " bodyfile=\"" << bodyDef->absFilePath() << "\"";
+      }
       t << " bodystart=\"" << md->getStartBodyLine() << "\" bodyend=\"" 
         << md->getEndBodyLine() << "\"";
     }
@@ -824,7 +856,19 @@ static void generateXMLSection(Definition *d,QTextStream &ti,QTextStream &t,
                       MemberList *ml,const char *kind,const char *header=0,
                       const char *documentation=0)
 {
-  if (ml->count()==0) return; // empty list
+  MemberListIterator mli(*ml);
+  MemberDef *md;
+  int count=0;
+  for (mli.toFirst();(md=mli.current());++mli)
+  {
+    // namespace members are also inserted in the file scope, but 
+    // to prevent this duplication in the XML output, we filter those here.
+    if (d->definitionType()!=Definition::TypeFile || md->getNamespaceDef()==0)
+    {
+      count++;
+    }
+  }
+  if (count==0) return; // empty list
 
   t << "      <sectiondef kind=\"" << kind << "\">" << endl;
   if (header)
@@ -837,11 +881,14 @@ static void generateXMLSection(Definition *d,QTextStream &ti,QTextStream &t,
     writeXMLDocBlock(t,d->docFile(),d->docLine(),d,0,documentation);
     t << "</description>" << endl;
   }
-  MemberListIterator mli(*ml);
-  MemberDef *md;
   for (mli.toFirst();(md=mli.current());++mli)
   {
-    generateXMLForMember(md,ti,t,d);
+    // namespace members are also inserted in the file scope, but 
+    // to prevent this duplication in the XML output, we filter those here.
+    if (d->definitionType()!=Definition::TypeFile || md->getNamespaceDef()==0)
+    {
+      generateXMLForMember(md,ti,t,d);
+    }
   }
   t << "      </sectiondef>" << endl;
 }
@@ -896,7 +943,7 @@ static void writeInnerClasses(const ClassSDict *cl,QTextStream &t)
     ClassDef *cd;
     for (cli.toFirst();(cd=cli.current());++cli)
     {
-      if (cd->name().find('@')!=-1) // skip anonymous scopes
+      if (cd->name().find('@')==-1) // skip anonymous scopes
       {
         t << "    <innerclass refid=\"" << cd->getOutputFileBase()
           << "\">" << convertToXML(cd->name()) << "</innerclass>" << endl;
@@ -913,7 +960,7 @@ static void writeInnerNamespaces(const NamespaceSDict *nl,QTextStream &t)
     NamespaceDef *nd;
     for (nli.toFirst();(nd=nli.current());++nli)
     {
-      if (nd->name().find('@')!=-1) // skip anonymouse scopes
+      if (nd->name().find('@')==-1) // skip anonymouse scopes
       {
         t << "    <innernamespace refid=\"" << nd->getOutputFileBase()
           << "\">" << convertToXML(nd->name()) << "</innernamespace>" << endl;
@@ -1191,6 +1238,11 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
     << cd->getDefLine() << "\"";
     if (cd->getStartBodyLine()!=-1)
     {
+      FileDef *bodyDef = cd->getBodyDef();
+      if (bodyDef)
+      {
+        t << " bodyfile=\"" << bodyDef->absFilePath() << "\"";
+      }
       t << " bodystart=\"" << cd->getStartBodyLine() << "\" bodyend=\"" 
         << cd->getEndBodyLine() << "\"";
     }
@@ -1535,6 +1587,7 @@ static void generateXMLForPage(PageDef *pd,QTextStream &ti,bool isExample)
   t << "\" kind=\"" << kindName << "\">" << endl;
   t << "    <compoundname>" << convertToXML(pd->name()) 
     << "</compoundname>" << endl;
+
   SectionInfo *si = Doxygen::sectionDict.find(pd->name());
   if (si)
   {
